<?php
/**
 * Plugin Name:  Musart Shortcodes
 * Description:  Shortcodes for Musart
 * Version:      1.0.0
 * Author:       nK
 * Author URI:   https://nkdev.info
 * License:      GPLv2 or later
 * License URI:  https://www.gnu.org/licenses/gpl-2.0.html
 * Text Domain:  musart-shortcodes
*/

// Make sure we don't expose any info if called directly
if ( !function_exists( 'add_action' ) ) {
    echo 'Hi there!  I\'m just a plugin, not much I can do when called directly.';
    exit;
}

/**
 * Musart_Shortcodes Class
 */
if (!class_exists( 'Musart_Shortcodes' )) :
    class Musart_Shortcodes {

        /**
         * The single class instance.
         */
        private static $_instance = null;

        /**
         * Main Instance
         * Ensures only one instance of this class exists in memory at any one time.
         */
        public static function instance () {
            if ( is_null( self::$_instance ) ) {
                self::$_instance = new self();
                self::$_instance->init_text_domain();
                self::$_instance->init_options();
                self::$_instance->init_hooks();

                // include helper files
                self::$_instance->include_dependencies();

                // clear caches
                self::$_instance->clear_expired_caches();

            }
            return self::$_instance;
        }

        public $plugin_path;
        public $plugin_url;
        public $plugin_name;
        public $plugin_version;
        public $plugin_slug;
        public $plugin_name_sanitized;

        public function __construct() {
            /* We do nothing here! */
        }

        public function init_text_domain () {
            load_plugin_textdomain( 'musart-shortcodes', false, dirname( plugin_basename(__FILE__) ) . '/languages/' );
        }

        public function init_options() {
            $this->plugin_path = plugin_dir_path(__FILE__);
            $this->plugin_url = plugin_dir_url(__FILE__);
        }

        public function init_hooks() {
            add_action( 'admin_init', array($this, 'admin_init') );
            add_action( 'wp_footer', array($this, 'audio_player'), 10 );
            add_action( 'init', array($this, 'audio_player_options'), 100 );
        }

        public function admin_init () {
            // get current plugin data
            $data = get_plugin_data(__FILE__);
            $this->plugin_name = $data['Name'];
            $this->plugin_version = $data['Version'];
            $this->plugin_slug = plugin_basename(__FILE__, '.php');
            $this->plugin_name_sanitized = basename(__FILE__, '.php');
        }

        public function audio_player() {
            if ( function_exists( 'musart_get_theme_mod' ) ) {
            ?>
            <?php  $audio_player_active_playlist = musart_get_theme_mod('audio_player_active_playlist');?>
            <?php global $enablePlayer; ?>
            <?php if ($enablePlayer || $audio_player_active_playlist): ?>
                <!--
                   START: Audio Player

                   Additional Classes:
                       nk-audio-player-autoplay
                       nk-audio-player-pin
                -->
                <div class="nk-audio-player-main nk-audio-player-pin">
                    <div class="container">
                        <div class="nk-audio-inner">
                            <div class="nk-audio-controls">
                                <div class="nk-audio-prev">
                                    <span class="ion-ios-rewind"></span>
                                </div>
                                <div class="nk-audio-play-pause">
                                    <div class="nk-audio-play">
                                        <span class="ion-play ml-3"></span>
                                    </div>
                                    <div class="nk-audio-pause">
                                        <span class="ion-pause"></span>
                                    </div>
                                </div>
                                <div class="nk-audio-next">
                                    <span class="ion-ios-fastforward"></span>
                                </div>
                            </div>
                            <div class="nk-audio-title">
                                <div>
                                </div>
                            </div>
                            <div class="nk-audio-time"></div>
                            <!-- Volume controller will be automatically removed on iOs devices, because of limitation of volume control -->
                            <div class="nk-audio-volume">
                                <div class="nk-audio-volume-icon">
                                    <div class="nk-audio-volume-icon-muted">
                                        <span class="ion-android-volume-off"></span>
                                    </div>
                                    <div class="nk-audio-volume-icon-small">
                                        <span class="ion-android-volume-mute"></span>
                                    </div>
                                    <div class="nk-audio-volume-icon-half">
                                        <span class="ion-android-volume-down"></span>
                                    </div>
                                    <div class="nk-audio-volume-icon-full">
                                        <span class="ion-android-volume-up"></span>
                                    </div>
                                </div>
                                <div class="nk-audio-volume-inner">
                                    <div class="nk-audio-volume-current"></div>
                                </div>
                            </div>
                            <div class="nk-audio-settings">
                                <div class="nk-audio-loop" title="<?php esc_attr_e('Loop', '@@text_domain');?>">
                                    <span class="ion-loop"></span>
                                </div>
                                <div class="nk-audio-shuffle" title="<?php esc_attr_e('Shuffle', '@@text_domain');?>">
                                    <span class="ion-shuffle"></span>
                                </div>
                                <div class="nk-audio-playlist" title="<?php esc_attr_e('Show/Hide Playlist', '@@text_domain');?>">
                                    <span class="ion-android-list"></span>
                                </div>
                                <div class="nk-audio-pin" title="<?php esc_attr_e('Pin/Unpin Player', '@@text_domain');?>">
                                    <span class="ion-pin"></span>
                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="nk-audio-progress">
                        <div class="nk-audio-progress-current"></div>
                    </div>
                    <div class="nk-audio-player-playlist">
                        <div class="nano">
                            <div class="nano-content">
                                <ul class="nk-audio-player-playlist-inner"></ul>
                            </div>
                        </div>
                    </div>
                </div>
                <div class="nk-side-buttons nk-side-buttons-left hidden-md-up">
                    <ul>
                        <li><a href="#" class="nk-audio-pin"><span class="ion-ios-musical-notes"></span></a></li>
                    </ul>
                </div>
                <!-- END: Audio Player -->
            <?php endif; ?>
            <?php $audio_player_show = musart_get_theme_mod('audio_player_show');?>
            <?php if($audio_player_show):?>
                <?php if(isset($audio_player_active_playlist) && is_numeric($audio_player_active_playlist) && $audio_player_active_playlist != 0):?>
                    <?php
                    $playlist_tracks = musart_get_theme_mod('playlist_tracks', true, $audio_player_active_playlist);
                    $tracks = array();
                    if ( isset( $playlist_tracks ) && ! empty( $playlist_tracks ) && is_array( $playlist_tracks ) ) {
                        foreach($playlist_tracks as $key=>$track){
                            $tracks[$key]['audio'] = $track['track']['id'];
                            $tracks[$key]['download'] = $track['downloading'];
                            $tracks[$key]['buy_link'] = $track['buy_link'];
                        }
                    }
                    ?>
                    <?php if (isset($tracks) && is_array($tracks) && !empty($tracks)):?>
                        <?php
                        //define flag for show player
                        global $enablePlayer;
                        $enablePlayer = true;
                        $link_pattern = '|^http(s)?://[a-z0-9-]+(.[a-z0-9-]+)*(:[0-9]+)?(/.*)?$|i';
                        ?>
                        <ul class="nk-audio-playlist nk-audio-playlist-hidden active">
                            <?php foreach ($tracks as $track):?>
                                <?php  if (isset($track['audio']) && !empty($track['audio'])):?>
                                    <?php
                                    if (is_numeric($track['audio'])) {
                                        $meta_audio = get_post_meta($track['audio'], '_wp_attachment_metadata', true);
                                        $album = isset($meta_audio['album']) ? $meta_audio['album'] : '';
                                        $track_length = isset($meta_audio['length_formatted']) ? $meta_audio['length_formatted'] : '';
                                        $url = wp_get_attachment_url($track['audio']);
                                        $media_title = get_the_title($track['audio']);
                                        $downloadable = 'false';
                                        $purchase = '';
                                        if(isset($track['download']) && $track['download'] != false){
                                            $downloadable = 'true';
                                        }
                                    }?>
                                    <?php  if (preg_match($link_pattern, $url)):?>
                                        <li data-src="<?php echo esc_url($url);?>" data-downloadable="<?php echo esc_attr($downloadable);?>">
                                            <?php
                                            if (isset($media_title) || isset($album)): ?>
                                                <div class="nk-audio-playlist-title">
                                                    <strong><?php echo esc_html(isset( $album ) ? $album : '');?></strong> <?php echo esc_html((isset($media_title) && isset($album)) ? ' - ' : '') . esc_html(isset($media_title) ? $media_title : '');?>
                                                </div>
                                            <?php endif;?>
                                            <?php
                                            if ((isset($track['download']) && $track['download'] != false) || (isset($track['buy_link']) && preg_match($link_pattern, $track['buy_link']))) {
                                                echo '<div class="nk-audio-playlist-buttons">';
                                                if (isset($track['buy_link']) && preg_match($link_pattern, $track['buy_link'])) {
                                                    echo '<a href="' . esc_url($track['buy_link']) . '" target="_blank"><span class="ion-bag"></span></a>';
                                                }
                                                if (isset($track['download']) && $track['download'] != false) {
                                                    echo '<a href="' . esc_url($url) . '" download><span class="fas fa-download"></span></a>';
                                                }
                                                echo '</div>';
                                            }
                                            if (isset($track_length) && !empty($track_length)) {
                                                echo '<div class="nk-audio-playlist-duration">'.esc_html($track_length).'</div>';
                                            }
                                            ?>
                                        </li>
                                    <?php endif; ?>
                                <?php endif; ?>
                            <?php endforeach;?>
                        </ul>
                    <?php endif; ?>
                <?php endif; ?>
            <?php endif; ?>
<?php
            }
        }

        public function audio_player_options() {
            if ( class_exists( 'Musart_Options' ) ) {
                Musart_Options::add_section('audio_player', array(
                    'title' => esc_html__('Audio Player', '@@text_domain'),
                    'priority' => 12,
                    'icon' => 'fas fa-music'
                ));

                Musart_Options::add_field( array(
                    'type' => 'toggle',
                    'settings' => 'audio_player_show',
                    'label' => esc_html__('Show Audio Player', '@@text_domain'),
                    'section' => 'audio_player',
                    'default' => 'off',
                    'priority' => 10,
                ));
                //add all playlist posts for show in post_id option
                $args = array(
                    'posts_per_page' => -1,
                    'post_type' => 'playlist',
                );
                $posts = new WP_Query($args);
                $post_list = array();
                $post_list[] = esc_attr__('Disable', '@@text_domain');
                foreach ($posts->posts as $post) {
                    $post_list[$post->ID] = $post->post_title;
                }
                Musart_Options::add_field( array(
                    'type' => 'select',
                    'settings' => 'audio_player_active_playlist',
                    'label' => esc_html__('Select Active Playlist', '@@text_domain'),
                    'section' => 'audio_player',
                    'default' => false,
                    'priority' => 10,
                    'multiple' => 0,
                    'choices' => $post_list,
                    'active_callback' => array(
                        array(
                            'setting' => 'audio_player_show',
                            'operator' => '==',
                            'value' => true,
                        ),
                    ),
                ));
            }
        }
        // include
        private function include_dependencies () {
            require_once($this->plugin_path . '_all.php');

            /* include all shortcodes */
            require_once($this->plugin_path . "/shortcodes/nk-title.php");
            require_once($this->plugin_path . "/shortcodes/nk-text.php");
            require_once($this->plugin_path . "/shortcodes/nk-block-quote.php");
            require_once($this->plugin_path . "/shortcodes/nk-button.php");

            require_once($this->plugin_path . "/shortcodes/nk-icon-box.php");
            require_once($this->plugin_path . "/shortcodes/nk-info-box.php");
            require_once($this->plugin_path . "/shortcodes/nk-counter.php");
            require_once($this->plugin_path . "/shortcodes/nk-image-box.php");
            require_once($this->plugin_path . "/shortcodes/nk-gallery-images.php");
            require_once($this->plugin_path . "/shortcodes/nk-plain-video.php");
            require_once($this->plugin_path . "/shortcodes/nk-testimonial.php");

            require_once($this->plugin_path . "/shortcodes/nk-countdown.php");

            require_once($this->plugin_path . "/shortcodes/nk-instagram.php");
            require_once($this->plugin_path . "/shortcodes/nk-twitter.php");
            require_once($this->plugin_path . "/shortcodes/nk-posts-list.php");
            require_once($this->plugin_path . "/shortcodes/nk-separator.php");
            require_once($this->plugin_path . "/shortcodes/nk-playlist.php");
            require_once($this->plugin_path . "/shortcodes/nk-plain-audio.php");
            require_once($this->plugin_path . "/shortcodes/nk-events-list.php");
            require_once($this->plugin_path . "/shortcodes/nk-social.php");
            require_once($this->plugin_path . "/shortcodes/nk-contact.php");
        }

        /**
         * Options
         */
        private function get_options () {
            $options_slug = 'musart_shortcodes_options';
            return unserialize( get_option($options_slug, 'a:0:{}') );
        }
        public function update_option ($name, $value) {
            $options_slug = 'musart_shortcodes_options';
            $options = self::get_options();
            $options[self::sanitize_key($name)] = $value;
            update_option($options_slug, serialize($options));
        }
        public function get_option ($name, $default = null) {
            $options = self::get_options();
            $name = self::sanitize_key($name);
            return isset($options[$name]) ? $options[$name] : $default;
        }
        private function sanitize_key ($key) {
            return preg_replace( '/[^A-Za-z0-9\_]/i', '', str_replace( array( '-', ':' ), '_', $key ) );
        }

        /**
         * Cache
         * $time in seconds
         */
        private function get_caches () {
            $caches_slug = 'cache';
            return $this->get_option($caches_slug, array());
        }
        public function set_cache ($name, $value, $time = 3600) {
            if(!$time || $time <= 0) {
                return;
            }
            $caches_slug = 'cache';
            $caches = self::get_caches();

            $caches[self::sanitize_key($name)] = array(
                'value'   => $value,
                'expired' => time() + ((int) $time ? $time : 0)
            );
            $this->update_option($caches_slug, $caches);
        }
        public function get_cache ($name, $default = null) {
            $caches = self::get_caches();
            $name = self::sanitize_key($name);
            return isset($caches[$name]['value']) ? $caches[$name]['value'] : $default;
        }
        public function clear_cache ($name) {
            $caches_slug = 'cache';
            $caches = self::get_caches();
            $name = self::sanitize_key($name);
            if(isset($caches[$name])) {
                $caches[$name] = null;
                $this->update_option($caches_slug, $caches);
            }
        }
        public function clear_expired_caches () {
            $caches_slug = 'cache';
            $caches = self::get_caches();
            foreach($caches as $k => $cache) {
                if(isset($cache) && isset($cache['expired']) && $cache['expired'] < time()) {
                    $caches[$k] = null;
                }
            }
            $this->update_option($caches_slug, $caches);
        }

    }
endif;

if (!function_exists( 'musart_shortcodes' )) :
    function musart_shortcodes () {
        return Musart_Shortcodes::instance();
    }
endif;
add_action('plugins_loaded', 'musart_shortcodes' );
