<?php
/**
 * nK Image Box
 *
 * Example:
 * [nk_image_box image="12" image_size="full" link="https://google.com" content_vertical_align="center" style="1" no_effect="false" hovered="false"]My Content[/nk_image_box]
 */

add_shortcode('nk_image_box', 'nk_image_box');
if (!function_exists('nk_image_box')) :
    function nk_image_box($atts, $content = null)
    {
        extract(shortcode_atts(array(
            "image" => "",
            "image_size" => "",
            "link" => "",
            "content_vertical_align" => "center",
            "style" => "1",
            "no_effect" => "",
            "hovered" => "",
            "box_line" => "",
            "class" => "",
        ), $atts));

        // image
        $image_str = $class_str = $overlay_str = '';
        if (musart_nk_check($image)) {
            $image_atts = array();
            if($style == 2) {
                $image_atts = array('data-from'=>'1.1');
            }
            if (musart_nk_check($image)) {
                $image_str = wp_get_attachment_image( $image, $image_size, false, $image_atts );
            }
        }

        // link
        $link_atts = '';
        $tag = '';
        $link_str='';
        if (musart_nk_check($link) && function_exists('vc_build_link')) {
            $link = vc_build_link($link);

            if(isset($link['url']) && $link['url']) {
                $tag = 'a';
                $link_atts = ' href="' . esc_attr($link['url']) . '"';

                if(isset($link['title']) && $link['title']) {
                    $link_atts .= ' title="' . esc_attr($link['title']) . '"';
                }
                if(isset($link['target']) && $link['target']) {
                    $link_atts .= ' target="' . esc_attr($link['target']) . '"';
                }
                if(isset($link['rel']) && $link['rel']) {
                    $link_atts .= ' rel="' . esc_attr($link['rel']) . '"';
                }
                $link_str = '<' . $tag . ' ' . $link_atts . ' class="nk-image-box-link"></' . $tag . '>';
            }

        } else if (musart_nk_check($link)) {
            $tag = 'a';
            $link_atts = ' href="' . esc_attr($link) . '"';
            $link_str = '<' . $tag . ' ' . $link_atts . ' class="nk-image-box-link"></' . $tag . '>';
        }
        // no effect
        if (musart_nk_check($no_effect)) {
            $class .= ' nk-no-effect';
        }

        // hovered
        if (musart_nk_check($hovered)) {
            $class .= ' hover';
        }

        // additional classname for custom styles VC
        $class .= musart_get_css_tab_class($atts);

        if(musart_nk_check($style)){
            $class .= ' nk-image-box-' . $style;
            if(isset($content) && !empty($content)){
                $overlay_str = '<div class="' . musart_sanitize_class('nk-image-box-overlay nk-image-box-' . $content_vertical_align) . '">
                                <div>
                                    ' . do_shortcode($content) . '
                                </div>
                            </div>';
            }
        } else {
            $class .= ' nk-image-box';
        }
        if(musart_nk_check($box_line)){
            $class .= ' nk-box-line';
        }
        if(musart_nk_check(trim($class))){
            $class_str = ' class="' . musart_sanitize_class(trim($class)) . '"';
        }

        return '<div' . $class_str . '>
                    ' . $link_str . '
                    ' . $image_str . '
                    ' . $overlay_str . '
                </div>';
    }
endif;

add_action( 'after_setup_theme', 'vc_nk_image_box', 100 );
if ( ! function_exists( 'vc_nk_image_box' ) ) :
    function vc_nk_image_box() {
        if(function_exists('vc_map')) {
            /* Register shortcode with Visual Composer */
            vc_map( array(
                'name' => esc_html__('nK Image Box', '@@text_domain'),
                'base' => 'nk_image_box',
                'controls' => 'full',
                'category' => 'nK',
                'icon'     => 'icon-nk icon-nk-image-box',
                "as_parent" => array('only' => array('nk_title', 'nk_text', 'nk_button')),
                "content_element" => true,
                "js_view"  => 'VcColumnView',
                'params' => array_merge(array(
                    array(
                        'type' => 'attach_image',
                        'heading' => esc_html__("Select Image", '@@text_domain'),
                        'param_name' => 'image',
                    ),
                    array(
                        'type'       => 'dropdown',
                        'heading'    => esc_html__('Image Size', '@@text_domain'),
                        'param_name' => 'image_size',
                        'std'        => 'full',
                        'value'      => musart_get_image_sizes(),
                        'description' => ''
                    ),
                    array(
                        'type'       => 'dropdown',
                        'heading'    => esc_html__('Effect', '@@text_domain'),
                        'param_name' => 'style',
                        'std'        => '1',
                        'value'      => array(
                            esc_html__('Disable', '@@text_domain')  => false,
                            esc_html__('Style 1', '@@text_domain')  => '1',
                            esc_html__('Style 1a', '@@text_domain')  => '1-a',
                            esc_html__('Style 2', '@@text_domain')  => '2',
                            esc_html__('Style 3', '@@text_domain')  => '3',
                            esc_html__('Style 4', '@@text_domain')  => '4',
                            esc_html__('Style 5', '@@text_domain')  => '5',
                        ),
                        'description' => ''
                    ),
                    array(
                        'type'       => 'vc_link',
                        'heading'    => esc_html__('Link', '@@text_domain'),
                        'param_name' => 'link',
                    ),
                    array(
                        'type'       => 'dropdown',
                        'heading'    => esc_html__('Content Vertical Align', '@@text_domain'),
                        'param_name' => 'content_vertical_align',
                        'std'        => 'center',
                        'value'      => array(
                            esc_html__('Top', '@@text_domain')  => 'top',
                            esc_html__('Center', '@@text_domain')  => 'center',
                            esc_html__('Bottom', '@@text_domain')  => 'bottom',
                        ),
                        'description' => ''
                    ),
                    array(
                        'param_name'  => 'no_effect',
                        'heading'     => esc_html__('No Hover Effect', '@@text_domain'),
                        'type'        => 'checkbox',
                        'value'       => array( '' => true ),
                    ),
                    array(
                        'param_name'  => 'hovered',
                        'heading'     => esc_html__('Hovered', '@@text_domain'),
                        'type'        => 'checkbox',
                        'value'       => array( '' => true ),
                    ),
                    array(
                        'param_name'  => 'box_line',
                        'heading'     => esc_html__('Box Line', '@@text_domain'),
                        'type'        => 'checkbox',
                        'value'       => array( '' => true ),
                    ),
                    array(
                        'type'        => 'textfield',
                        'heading'     => esc_html__('Custom Classes', '@@text_domain'),
                        'param_name'  => 'class',
                        'value'       => '',
                        'description' => '',
                    )
                ), musart_get_css_tab())
            ) );
        }
    }
endif;


//Your "container" content element should extend WPBakeryShortCodesContainer class to inherit all required functionality
if ( class_exists( 'WPBakeryShortCodesContainer' ) ) {
    class WPBakeryShortCode_nk_image_box extends WPBakeryShortCodesContainer {
    }
}
