<?php
/**
 * Custom Walker for Walker_Nav_Menu
 *
 * We're separating this class from the plugin file because Walker_Nav_Menu
 * is only loaded on the wp-admin/nav-menus.php page.
 * Thanks for idea Dzikri Aziz <kvcrvt@gmail.com> and his project wp-menu-icons: https://github.com/kucrut/wp-menu-icons/
 *
 * @package musart
 */
/* Add mega menu*/
if (!function_exists('musart_mega_menu_fields')) :
    function musart_mega_menu_fields($item_id, $item, $depth, $args, $id)
    {
        $result = '';
        // Get WordPress' media upload URL
        $upload_link = esc_url(get_upload_iframe_src('image', $item_id));
        // See if there's a media id already saved as post meta
        $img_id = $item->image;
        // Get the image src
        $img_src = wp_get_attachment_image_src($img_id, 'full');
        // For convenience, see if the array is valid
        $have_img = is_array($img_src);
        ?>
        <p class="field-link-mega description">
            <label for="edit-menu-item-mega-<?php echo esc_attr( $item_id ); ?>">
                <input type="checkbox" id="edit-menu-item-mega-<?php echo esc_attr( $item_id ); ?>" value="on" name="menu-item-mega[<?php echo esc_attr( $item_id ); ?>]" <?php echo checked($item->mega, 'on', false); ?>/>
            <?php echo esc_html__( 'Mega Menu', 'musart' ); ?>
            </label>
        </p>
        <p class="field-link-mega description">
            <label for="edit-menu-item-column-labels-<?php echo esc_attr( $item_id ); ?>">
                <input type="checkbox" id="edit-menu-item-column-labels-<?php echo esc_attr( $item_id ); ?>" value="on" name="menu-item-column-labels[<?php echo esc_attr( $item_id ); ?>]" <?php echo checked($item->column_labels, 'on', false); ?>/>
                <?php echo esc_html__( 'Column Labels', 'musart' ); ?>
            </label>
        </p>
        <div class="musart-menu-bg-image">
            <div class="custom-img-container">
                <?php if ($have_img): ?>
                <img src="<?php echo esc_url( $img_src[0] ); ?>" style="max-width:100%;"/>
                <?php endif; ?>
            </div>
            <p class="hide-if-no-js">
                <?php $add_button_class = $have_img ? ' hidden' : ''; ?>
                <a class="upload-custom-img button<?php echo musart_sanitize_class($add_button_class); ?>" href="<?php echo esc_url( $upload_link ); ?>">
                    <?php echo esc_html__( 'Mega Menu Background Image', 'musart' ); ?>
                </a>
                <?php $remove_button_class = !$have_img ? ' hidden' : ''; ?>
                <a class="delete-custom-img <?php echo musart_sanitize_class($remove_button_class); ?>" href="#">
                    <?php echo esc_html__('Remove this image', 'musart');?>
                </a>
            </p>
            <input class="custom-img-id" id="edit-menu-item-img-<?php echo esc_attr( $item_id ); ?>" name="menu-item-img[<?php echo esc_attr( $item_id ); ?>]" type="hidden" value="<?php echo esc_attr( $img_id ); ?>"/>
        </div>
        <?php
    }
endif;
add_action('wp_nav_menu_item_custom_fields', 'musart_mega_menu_fields', 10, 5);

if (!function_exists('musart_media_load')) :
    function musart_media_load($current_screen)
    {
        if ($current_screen->base == 'nav-menus' && $current_screen->id == 'nav-menus') {
            wp_enqueue_media();
        }
    }
endif;
add_action('current_screen', 'musart_media_load');
/**
 * Add Mega Menu checkbox
 */
// add custom menu fields to menu
add_filter('wp_setup_nav_menu_item', 'musart_setup_nam_menu_item');
if (!function_exists('musart_setup_nam_menu_item')) :
    function musart_setup_nam_menu_item($menu_item)
    {
        $menu_item->mega = get_post_meta($menu_item->ID, '_menu_item_mega', true);
        $menu_item->column_labels = get_post_meta($menu_item->ID, '_menu_item_column_labels', true);
        $menu_item->image = get_post_meta($menu_item->ID, '_menu_item_img', true);
        return $menu_item;
    }
endif;
// save menu custom fields
add_action('wp_update_nav_menu_item', 'musart_update_nav_menu_item', 10, 3);
if (!function_exists('musart_update_nav_menu_item')) :
    function musart_update_nav_menu_item($menu_id, $menu_item_db_id, $args)
    {
        // Check if element is properly sent
        if ((isset($_REQUEST['menu-item-mega']) && is_array($_REQUEST['menu-item-mega'])) || (isset($_REQUEST['menu-item-img']) && is_array($_REQUEST['menu-item-img'])) || (isset($_REQUEST['menu-item-column-labels']) && is_array($_REQUEST['menu-item-column-labels']))) {

            $mega = isset($_REQUEST['menu-item-mega'][$menu_item_db_id]) ? $_REQUEST['menu-item-mega'][$menu_item_db_id] : false;
            update_post_meta($menu_item_db_id, '_menu_item_mega', $mega);

            $column_labels = isset($_REQUEST['menu-item-column-labels'][$menu_item_db_id]) ? $_REQUEST['menu-item-column-labels'][$menu_item_db_id] : false;
            update_post_meta($menu_item_db_id, '_menu_item_column_labels', $column_labels);

            $image = isset($_REQUEST['menu-item-img'][$menu_item_db_id]) ? $_REQUEST['menu-item-img'][$menu_item_db_id] : false;
            update_post_meta($menu_item_db_id, '_menu_item_img', $image);
        }

    }
endif;
// edit menu walker

add_filter('wp_edit_nav_menu_walker', 'musart_edit_nav_menu_walker', 10, 2);
if (!function_exists('musart_edit_nav_menu_walker')) :
    function musart_edit_nav_menu_walker($walker, $menu_id)
    {
        return 'Musart_Walker_Nav_Menu_Edit';
    }
endif;

// extends from Walker_Nav_Menu, because Walker_Nav_Menu_Edit don't available.
class Musart_Walker_Nav_Menu_Edit extends Walker_Nav_Menu
{
    /**
     * Start the element output.
     *
     * @see Walker_Nav_Menu::start_el()
     * @since 3.0.0
     *
     * @global int $_wp_nav_menu_max_depth
     *
     * @param string $output Passed by reference. Used to append additional content.
     * @param object $item Menu item data object.
     * @param int $depth Depth of menu item. Used for padding.
     * @param array $args Not used.
     * @param int $id Not used.
     */
    public function start_lvl(&$output, $depth = 0, $args = array())
    {
    }

    public function end_lvl(&$output, $depth = 0, $args = array())
    {
    }

    /**
     * Start the element output.
     *
     * @see Walker_Nav_Menu::start_el()
     * @since 3.0.0
     *
     * @global int $_wp_nav_menu_max_depth
     *
     * @param string $output Passed by reference. Used to append additional content.
     * @param object $item Menu item data object.
     * @param int $depth Depth of menu item. Used for padding.
     * @param array $args Not used.
     * @param int $id Not used.
     */
    public function start_el(&$output, $item, $depth = 0, $args = array(), $id = 0)
    {
        global $_wp_nav_menu_max_depth;
        $_wp_nav_menu_max_depth = $depth > $_wp_nav_menu_max_depth ? $depth : $_wp_nav_menu_max_depth;

        ob_start();
        $item_id = esc_attr($item->ID);
        $removed_args = array(
            'action',
            'customlink-tab',
            'edit-menu-item',
            'menu-item',
            'page-tab',
            '_wpnonce',
        );

        $original_title = false;
        if ('taxonomy' == $item->type) {
            $original_title = get_term_field('name', $item->object_id, $item->object, 'raw');
            if (is_wp_error($original_title))
                $original_title = false;
        } elseif ('post_type' == $item->type) {
            $original_object = get_post($item->object_id);
            $original_title = get_the_title($original_object->ID);
        } elseif ('post_type_archive' == $item->type) {
            $original_object = get_post_type_object($item->object);
            if ($original_object) {
                $original_title = $original_object->labels->archives;
            }
        }

        $classes = array(
            'menu-item menu-item-depth-' . $depth,
            'menu-item-' . esc_attr($item->object),
            'menu-item-edit-' . ((isset($_GET['edit-menu-item']) && $item_id == $_GET['edit-menu-item']) ? 'active' : 'inactive'),
        );

        $title = $item->title;

        if (!empty($item->_invalid)) {
            $classes[] = 'menu-item-invalid';
            /* translators: %s: title of menu item which is invalid */
            $title = sprintf(esc_html('%s (Invalid)'), $item->title);
        } elseif (isset($item->post_status) && 'draft' == $item->post_status) {
            $classes[] = 'pending';
            /* translators: %s: title of menu item in draft status */
            $title = sprintf(esc_html('%s (Pending)'), $item->title);
        }

        $title = (!isset($item->label) || '' == $item->label) ? $title : $item->label;

        $submenu_text = '';
        if (0 == $depth)
            $submenu_text = 'display: none;';

        ?>
    <li id="menu-item-<?php echo esc_attr( $item_id ); ?>" class="<?php echo implode(' ', $classes); ?>">
        <div class="menu-item-bar">
            <div class="menu-item-handle">
                <span class="item-title"><span class="menu-item-title"><?php echo esc_html($title); ?></span> <span
                        class="is-submenu" style="<?php echo esc_attr( $submenu_text ); ?>"><?php esc_html_e('sub item', 'musart'); ?></span></span>
					<span class="item-controls">
						<span class="item-type"><?php echo esc_html($item->type_label); ?></span>
						<span class="item-order hide-if-js">
							<a href="<?php
                            echo wp_nonce_url(
                                add_query_arg(
                                    array(
                                        'action' => 'move-up-menu-item',
                                        'menu-item' => $item_id,
                                    ),
                                    remove_query_arg($removed_args, admin_url('nav-menus.php'))
                                ),
                                'move-menu_item'
                            );
                            ?>" class="item-move-up" aria-label="<?php esc_attr_e('Move up', 'musart') ?>">&#8593;</a>
							|
							<a href="<?php
                            echo wp_nonce_url(
                                add_query_arg(
                                    array(
                                        'action' => 'move-down-menu-item',
                                        'menu-item' => $item_id,
                                    ),
                                    remove_query_arg($removed_args, admin_url('nav-menus.php'))
                                ),
                                'move-menu_item'
                            );
                            ?>" class="item-move-down" aria-label="<?php esc_attr_e('Move down', 'musart') ?>">&#8595;</a>
						</span>
						<a class="item-edit" id="edit-<?php echo esc_attr( $item_id ); ?>" href="<?php
                        echo (isset($_GET['edit-menu-item']) && $item_id == $_GET['edit-menu-item']) ? admin_url('nav-menus.php') : add_query_arg('edit-menu-item', $item_id, remove_query_arg($removed_args, admin_url('nav-menus.php#menu-item-settings-' . $item_id)));
                        ?>" aria-label="<?php esc_attr_e('Edit menu item', 'musart'); ?>"><?php esc_html_e('Edit', 'musart'); ?></a>
					</span>
            </div>
        </div>

        <div class="menu-item-settings wp-clearfix" id="menu-item-settings-<?php echo esc_attr( $item_id ); ?>">
            <?php if ('custom' == $item->type) : ?>
                <p class="field-url description description-wide">
                    <label for="edit-menu-item-url-<?php echo esc_attr( $item_id ); ?>">
                        <?php esc_html_e('URL', 'musart'); ?><br/>
                        <input type="text" id="edit-menu-item-url-<?php echo esc_attr( $item_id ); ?>"
                               class="widefat code edit-menu-item-url" name="menu-item-url[<?php echo esc_attr( $item_id ); ?>]"
                               value="<?php echo esc_attr($item->url); ?>"/>
                    </label>
                </p>
            <?php endif; ?>
            <p class="description description-wide">
                <label for="edit-menu-item-title-<?php echo esc_attr( $item_id ); ?>">
                    <?php esc_html_e('Navigation Label', 'musart'); ?><br/>
                    <input type="text" id="edit-menu-item-title-<?php echo esc_attr( $item_id ); ?>"
                           class="widefat edit-menu-item-title" name="menu-item-title[<?php echo esc_attr( $item_id ); ?>]"
                           value="<?php echo esc_attr($item->title); ?>"/>
                </label>
            </p>
            <p class="field-title-attribute field-attr-title description description-wide">
                <label for="edit-menu-item-attr-title-<?php echo esc_attr( $item_id ); ?>">
                    <?php esc_html_e('Title Attribute', 'musart'); ?><br/>
                    <input type="text" id="edit-menu-item-attr-title-<?php echo esc_attr( $item_id ); ?>"
                           class="widefat edit-menu-item-attr-title"
                           name="menu-item-attr-title[<?php echo esc_attr( $item_id ); ?>]"
                           value="<?php echo esc_attr($item->post_excerpt); ?>"/>
                </label>
            </p>
            <p class="field-link-target description">
                <label for="edit-menu-item-target-<?php echo esc_attr( $item_id ); ?>">
                    <input type="checkbox" id="edit-menu-item-target-<?php echo esc_attr( $item_id ); ?>" value="_blank"
                           name="menu-item-target[<?php echo esc_attr( $item_id ); ?>]"<?php checked($item->target, '_blank'); ?> />
                    <?php esc_html_e('Open link in a new tab', 'musart'); ?>
                </label>
            </p>
            <p class="field-css-classes description description-thin">
                <label for="edit-menu-item-classes-<?php echo esc_attr( $item_id ); ?>">
                    <?php esc_html_e('CSS Classes (optional)', 'musart'); ?><br/>
                    <input type="text" id="edit-menu-item-classes-<?php echo esc_attr( $item_id ); ?>"
                           class="widefat code edit-menu-item-classes" name="menu-item-classes[<?php echo esc_attr( $item_id ); ?>]"
                           value="<?php echo esc_attr(implode(' ', $item->classes)); ?>"/>
                </label>
            </p>
            <p class="field-xfn description description-thin">
                <label for="edit-menu-item-xfn-<?php echo esc_attr( $item_id ); ?>">
                    <?php esc_html_e('Link Relationship (XFN)', 'musart'); ?><br/>
                    <input type="text" id="edit-menu-item-xfn-<?php echo esc_attr( $item_id ); ?>"
                           class="widefat code edit-menu-item-xfn" name="menu-item-xfn[<?php echo esc_attr( $item_id ); ?>]"
                           value="<?php echo esc_attr($item->xfn); ?>"/>
                </label>
            </p>
            <p class="field-description description description-wide">
                <label for="edit-menu-item-description-<?php echo esc_attr( $item_id ); ?>">
                    <?php esc_html_e('Description', 'musart'); ?><br/>
                    <textarea id="edit-menu-item-description-<?php echo esc_attr( $item_id ); ?>"
                              class="widefat edit-menu-item-description" rows="3" cols="20"
                              name="menu-item-description[<?php echo esc_attr( $item_id ); ?>]"><?php echo esc_html($item->description); // textarea_escaped ?></textarea>
                    <span
                        class="description"><?php esc_html_e('The description will be displayed in the menu if the current theme supports it.', 'musart'); ?></span>
                </label>
            </p>
            <?php
            // add custom fields
            do_action('wp_nav_menu_item_custom_fields', $item->ID, $item, $depth, $args, $id);?>
            <fieldset class="field-move hide-if-no-js description description-wide">
                <span class="field-move-visual-label" aria-hidden="true"><?php esc_html_e('Move', 'musart'); ?></span>
                <button type="button" class="button-link menus-move menus-move-up"
                        data-dir="up"><?php esc_html_e('Up one', 'musart'); ?></button>
                <button type="button" class="button-link menus-move menus-move-down"
                        data-dir="down"><?php esc_html_e('Down one', 'musart'); ?></button>
                <button type="button" class="button-link menus-move menus-move-left" data-dir="left"></button>
                <button type="button" class="button-link menus-move menus-move-right" data-dir="right"></button>
                <button type="button" class="button-link menus-move menus-move-top"
                        data-dir="top"><?php esc_html_e('To the top', 'musart'); ?></button>
            </fieldset>

            <div class="menu-item-actions description-wide submitbox">
                <?php if ('custom' != $item->type && $original_title !== false) : ?>
                    <p class="link-to-original">
                        <?php printf('Original: %s', '<a href="' . esc_attr($item->url) . '">' . esc_html($original_title) . '</a>'); ?>
                    </p>
                <?php endif; ?>
                <a class="item-delete submitdelete deletion" id="delete-<?php echo esc_attr( $item_id ); ?>" href="<?php
                echo wp_nonce_url(
                    add_query_arg(
                        array(
                            'action' => 'delete-menu-item',
                            'menu-item' => $item_id,
                        ),
                        admin_url('nav-menus.php')
                    ),
                    'delete-menu_item_' . $item_id
                ); ?>"><?php esc_html_e('Remove', 'musart'); ?></a> <span class="meta-sep hide-if-no-js"> | </span> <a
                    class="item-cancel submitcancel hide-if-no-js" id="cancel-<?php echo esc_attr( $item_id ); ?>"
                    href="<?php echo esc_url(add_query_arg(array('edit-menu-item' => $item_id, 'cancel' => time()), admin_url('nav-menus.php')));
                    ?>#menu-item-settings-<?php echo esc_attr( $item_id ); ?>"><?php esc_html_e('Cancel', 'musart'); ?></a>
            </div>

            <input class="menu-item-data-db-id" type="hidden" name="menu-item-db-id[<?php echo esc_attr( $item_id ); ?>]"
                   value="<?php echo esc_attr( $item_id ); ?>"/>
            <input class="menu-item-data-object-id" type="hidden" name="menu-item-object-id[<?php echo esc_attr( $item_id ); ?>]"
                   value="<?php echo esc_attr($item->object_id); ?>"/>
            <input class="menu-item-data-object" type="hidden" name="menu-item-object[<?php echo esc_attr( $item_id ); ?>]"
                   value="<?php echo esc_attr($item->object); ?>"/>
            <input class="menu-item-data-parent-id" type="hidden" name="menu-item-parent-id[<?php echo esc_attr( $item_id ); ?>]"
                   value="<?php echo esc_attr($item->menu_item_parent); ?>"/>
            <input class="menu-item-data-position" type="hidden" name="menu-item-position[<?php echo esc_attr( $item_id ); ?>]"
                   value="<?php echo esc_attr($item->menu_order); ?>"/>
            <input class="menu-item-data-type" type="hidden" name="menu-item-type[<?php echo esc_attr( $item_id ); ?>]"
                   value="<?php echo esc_attr($item->type); ?>"/>
        </div><!-- .menu-item-settings-->
        <ul class="menu-item-transport"></ul>
        <?php
        $output .= ob_get_clean();
    }
}
