<?php
/**
 * Fix for body typography font Variants
 */
if (!function_exists('musart_enqueue_body_font_variants')) :
    function musart_enqueue_body_font_variants( $fonts ) {
        $bodyFamily = musart_get_theme_mod('typography_main_body');
        $titlesFamily = musart_get_theme_mod('typography_titles');

        $bodyFamily = $bodyFamily['font-family'];
        $titlesFamily = $titlesFamily['font-family'];

        $fonts[$bodyFamily] = array(
            'regular',
            'italic',
            '600',
        );
        $fonts[$titlesFamily] = array(
            'regular',
            '700'
        );

        return $fonts;
    }
endif;
add_filter( 'kirki/enqueue_google_fonts', 'musart_enqueue_body_font_variants' );

if (!function_exists('musart_customize_register')) :
    function musart_customize_register($wp_customize)
    {
        $wp_customize->get_setting('blogname')->transport = 'postMessage';
        $wp_customize->get_setting('blogdescription')->transport = 'postMessage';
        $wp_customize->get_setting('header_textcolor')->transport = 'postMessage';
        $wp_customize->get_control('site_icon')->priority = 10;

        $wp_customize->remove_control('display_header_text');

        $wp_customize->get_section('title_tagline')->title = 'General';
        $wp_customize->get_section('title_tagline')->priority = 1;

        $wp_customize->remove_section('colors');
        $wp_customize->remove_section('header_image');
        $wp_customize->remove_section('background_image');
    }
endif;
add_action('customize_register', 'musart_customize_register');

if(!function_exists('musart_get_sidebars')):
    function musart_get_sidebars(){
        global $wp_registered_sidebars;
        $sidebars = array();
        foreach ($wp_registered_sidebars as $k => $sidebar) {
            $sidebars[$sidebar['id']] = $sidebar['name'];
        }
        return $sidebars;
    }
endif;
if (!function_exists('musart_initial_kirki_options') && class_exists('Musart_Options')) {
    function musart_initial_kirki_options()
    {

        $sidebars = musart_get_sidebars();

        Musart_Options::add_config(array(
            'capability' => 'edit_theme_options',
            'option_type' => 'theme_mod',
        ));
        /**
         * Add panels
         */
        Musart_Options::add_panel('single_page', array(
            'priority' => 9,
            'title' => esc_html__('Single Page', 'musart'),
        ));
        Musart_Options::add_panel('single_post', array(
            'priority' => 9,
            'title' => esc_html__('Single Post', 'musart'),
            'icon' => ''
        ));

        Musart_Options::add_panel('archive', array(
            'priority' => 9,
            'title' => esc_html__('Archive', 'musart'),
            'icon' => ''
        ));
        Musart_Options::add_panel('search', array(
            'priority' => 9,
            'title' => esc_html__('Search', 'musart'),
            'icon' => ''
        ));
        /**
         * Add sections
         */
        Musart_Options::add_section('main_navigation', array(
            'title' => esc_html__('Main Navigation', 'musart'),
            'priority' => 9,
            'panel' => 'navigation',
        ));
        Musart_Options::add_section('side_navigation', array(
            'title' => esc_html__('Side Navigation', 'musart'),
            'priority' => 9,
            'panel' => 'navigation',
        ));
        Musart_Options::add_section('mobile_navigation', array(
            'title' => esc_html__('Mobile Navigation', 'musart'),
            'priority' => 9,
            'panel' => 'navigation',
        ));
        /**
         * 404 Page section
         */
        Musart_Options::add_section('not_found_page', array(
            'title' => esc_html__('404 Page', 'musart'),
            'priority' => 10,
        ));
        Musart_Options::add_panel('navigation', array(
            'priority' => 11,
            'title' => esc_html__('Navigation', 'musart'),
            'icon' => 'fa fa-bars'
        ));
        /**
         * Archive Page section
         */
        Musart_Options::add_section('archive_content', array(
            'title' => esc_html__('Content', 'musart'),
            'priority' => 12,
            'panel' => 'archive'
        ));
        Musart_Options::add_section('archive_header', array(
            'title' => esc_html__('Header', 'musart'),
            'priority' => 12,
            'panel' => 'archive'
        ));
        /**
         * Search Page section
         */
        Musart_Options::add_section('search_content', array(
            'title' => esc_html__('Content', 'musart'),
            'priority' => 12,
            'panel' => 'search'
        ));
        Musart_Options::add_section('search_header', array(
            'title' => esc_html__('Header', 'musart'),
            'priority' => 12,
            'panel' => 'search'
        ));
        /**
         * Background section
         */
        Musart_Options::add_section('background', array(
            'title' => esc_html__('Background', 'musart'),
            'priority' => 12,
            'icon' => 'fa fa-picture-o'
        ));
        Musart_Options::add_section('background_page_border', array(
            'title' => esc_html__('Page Border', 'musart'),
            'priority' => 12,
            'icon' => 'fa fa-square-o'
        ));
        Musart_Options::add_section('header', array(
            'title' => esc_html__('Header', 'musart'),
            'priority' => 12,
            'panel' => 'single_page',
        ));
        Musart_Options::add_section('single_page_content', array(
            'title' => esc_html__('Content', 'musart'),
            'priority' => 12,
            'panel' => 'single_page',
        ));

        /**
         * Cookie-alert section
         */
        Musart_Options::add_section('cookie_alert', array(
            'title' => esc_html__('Cookie-Alert', 'musart'),
            'priority' => 12,
            'icon' => 'fa fa-exclamation-circle'
        ));
        /**
         * Sharing section
         */
        Musart_Options::add_section('sharing_block', array(
            'title' => esc_html__('Sharing Block', 'musart'),
            'priority' => 12,
            'icon' => 'fa fa-share-alt'
        ));
        /**
         * Side buttons section
         */
        Musart_Options::add_section('side_buttons', array(
            'title' => esc_html__('Side Buttons', 'musart'),
            'priority' => 12,
            'icon' => 'fa fa-square'
        ));
        /**
         * Typography section
         */
        Musart_Options::add_section('typography', array(
            'title' => esc_html__('Typography', 'musart'),
            'priority' => 12,
            'icon' => 'fa fa-font'
        ));
        /**
         * Footer section
         */
        Musart_Options::add_section('footer', array(
            'title' => esc_html__('Footer', 'musart'),
            'priority' => 12,
            'icon' => 'fa fa-hand-o-down'
        ));
        /**
         * Single Page section
         */
        Musart_Options::add_section('single_page_header', array(
            'title' => esc_html__('Header', 'musart'),
            'priority' => 12,
            'panel' => 'single_page',
        ));
        Musart_Options::add_section('single_page_sidebar', array(
            'title' => esc_html__('Sidebar', 'musart'),
            'priority' => 12,
            'panel' => 'single_page',
        ));
        /**
         * Single Post section
         */
        Musart_Options::add_section('single_post_content', array(
            'title' => esc_html__('Content', 'musart'),
            'priority' => 12,
            'panel' => 'single_post',
        ));
        Musart_Options::add_section('single_post_header', array(
            'title' => esc_html__('Header', 'musart'),
            'priority' => 12,
            'panel' => 'single_post',
        ));
        Musart_Options::add_section('single_post_meta', array(
            'title' => esc_html__('Meta', 'musart'),
            'priority' => 12,
            'panel' => 'single_post',
        ));
        Musart_Options::add_section('single_post_sidebar', array(
            'title' => esc_html__('Sidebar', 'musart'),
            'priority' => 12,
            'panel' => 'single_post',
        ));

        /*
        General
        */
        Musart_Options::add_field( array(
            'type' => 'toggle',
            'settings' => 'page_boxed',
            'label' => esc_html__('Boxed Overall', 'musart'),
            'section' => 'title_tagline',
            'default' => 'off',
            'priority' => 10,
        ));
        Musart_Options::add_field( array(
            'type' => 'toggle',
            'settings' => 'enable_search_autofocus',
            'label' => esc_html__('Search Autofocus', 'musart'),
            'section' => 'title_tagline',
            'default' => 'on',
            'priority' => 10
        ));
        Musart_Options::add_field( array(
            'type' => 'number',
            'settings' => 'scroll_to_anchor_speed',
            'label' => esc_html__('Scroll To Anchor Speed', 'musart'),
            'section' => 'title_tagline',
            'default' => 700,
            'choices' => array(
                'min' => 0,
                'max' => 2000,
                'step' => 1,
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'text',
            'settings' => 'plain_video_icon',
            'label' => esc_html__('Plain Video Icon', 'musart'),
            'section' => 'title_tagline',
            'default' => 'fa fa-play',
            'priority' => 10,
            'description' => sprintf(wp_kses(__('Enter icon class. You can use <a href="%s" target="_blank">"ioicons"</a> and <a href="%2s" target="_blank">"Font Awesome"</a> icons.', 'musart'), array('a' => array('href' => array(), 'target' => array()))), esc_url("http://ionicons.com/"), esc_url("http://fontawesome.io/icons/")),
        ));
        Musart_Options::add_field( array(
            'type' => 'text',
            'settings' => 'gif_icon',
            'label' => esc_html__('Gif Icon', 'musart'),
            'section' => 'title_tagline',
            'default' => 'fa fa-hand-pointer-o',
            'priority' => 10,
            'description' => sprintf(wp_kses(__('Enter icon class. You can use <a href="%s" target="_blank">"ioicons"</a> and <a href="%2s" target="_blank">"Font Awesome"</a> icons.', 'musart'), array('a' => array('href' => array(), 'target' => array()))), esc_url("http://ionicons.com/"), esc_url("http://fontawesome.io/icons/")),
        ));
        /*
        Navigation Fields
        */
        /*
        Main Navigation Panel
        */
        Musart_Options::add_field( array(
            'type' => 'toggle',
            'settings' => 'main_navigation_show',
            'label' => esc_html__('Show', 'musart'),
            'section' => 'main_navigation',
            'default' => 'on',
            'priority' => 10,

        ));
        Musart_Options::add_field( array(
            'type' => 'toggle',
            'settings' => 'main_navigation_show_search',
            'label' => esc_html__('Search Button', 'musart'),
            'section' => 'main_navigation',
            'default' => 'on',
            'priority' => 10,
            'active_callback' => array(
                array(
                    'setting' => 'main_navigation_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        //social share
        Musart_Options::add_field( array(
            'type' => 'toggle',
            'settings' => 'main_navigation_show_share_button',
            'label' => esc_html__('Share Button', 'musart'),
            'description' => esc_html__('Required Sociality plugin' ,'musart'),
            'section' => 'main_navigation',
            'default' => 'on',
            'priority' => 10,
            'active_callback' => array(
                array(
                    'setting' => 'main_navigation_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'toggle',
            'settings' => 'main_navigation_light',
            'label' => esc_html__('Light Color', 'musart'),
            'section' => 'main_navigation',
            'default' => 'on',
            'priority' => 10,
            'active_callback' => array(
                array(
                    'setting' => 'main_navigation_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        /*
        Additional Classes
        */
        Musart_Options::add_field( array(
            'type' => 'toggle',
            'settings' => 'main_navigation_opaque',
            'label' => esc_html__('Opaque', 'musart'),
            'section' => 'main_navigation',
            'default' => 'off',
            'priority' => 10,
            'active_callback' => array(
                array(
                    'setting' => 'main_navigation_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'toggle',
            'settings' => 'main_navigation_transparent',
            'label' => esc_html__('Transparent', 'musart'),
            'section' => 'main_navigation',
            'default' => 'off',
            'priority' => 10,
            'active_callback' => array(
                array(
                    'setting' => 'main_navigation_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'toggle',
            'settings' => 'main_navigation_sticky',
            'label' => esc_html__('Sticky', 'musart'),
            'section' => 'main_navigation',
            'default' => 'on',
            'priority' => 10,
            'active_callback' => array(
                array(
                    'setting' => 'main_navigation_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'toggle',
            'settings' => 'main_navigation_autohide',
            'label' => esc_html__('Hide on Scroll', 'musart'),
            'section' => 'main_navigation',
            'default' => 'on',
            'priority' => 10,
            'active_callback' => array(
                array(
                    'setting' => 'main_navigation_show',
                    'operator' => '==',
                    'value' => true,
                ),
                array(
                    'setting' => 'main_navigation_sticky',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'select',
            'settings' => 'main_menu_align',
            'label' => esc_html__('Align', 'musart'),
            'section' => 'main_navigation',
            'default' => 'right',
            'priority' => 10,
            'choices' => array(
                'center' => esc_attr__('Center', 'musart'),
                'right' => esc_attr__('Right', 'musart'),
                'left' => esc_attr__('Left', 'musart')
            ),
            'active_callback' => array(
                array(
                    'setting' => 'main_navigation_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        /*
        Logo
        */
        Musart_Options::add_field( array(
            'type' => 'image',
            'settings' => 'main_navigation_logo',
            'label' => esc_html__('Logo', 'musart'),
            'section' => 'main_navigation',
            'default' => get_template_directory_uri() . '/assets/images/logo-music-label-light.png',
            'priority' => 10,
            'active_callback' => array(
                array(
                    'setting' => 'main_navigation_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'slider',
            'settings' => 'main_navigation_logo_width',
            'label' => esc_html__('Logo width', 'musart'),
            'section' => 'main_navigation',
            'default' => 70,
            'choices' => array(
                'min' => '20',
                'max' => '400',
                'step' => '1',
            ),
            'active_callback' => array(
                array(
                    'setting' => 'main_navigation_logo',
                    'operator' => '!=',
                    'value' => '',
                ),
                array(
                    'setting' => 'main_navigation_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'select',
            'settings' => 'main_navigation_logo_area',
            'label' => esc_html__('Logo Area', 'musart'),
            'section' => 'main_navigation',
            'default' => 'navigation',
            'priority' => 10,
            'choices' => array(
                'navigation' => esc_attr__('Navigation', 'musart'),
                'top' => esc_attr__('Top', 'musart')
            ),
            'active_callback' => array(
                array(
                    'setting' => 'main_navigation_logo',
                    'operator' => '!=',
                    'value' => '',
                ),
                array(
                    'setting' => 'main_navigation_show',
                    'operator' => '==',
                    'value' => true,
                ),
            )
        ));
        $menu_name = 'primary';
        $menu_array = array(
            false => esc_html__('Not Use', 'musart')
        );
        $locations = get_nav_menu_locations();
        if(is_array($locations) && isset($locations) && !empty($locations) && array_key_exists($menu_name, $locations)){
            $menu_items = wp_get_nav_menu_items(wp_get_nav_menu_object($locations[$menu_name]));
            if(is_array($menu_items) && isset($menu_items) && !empty($menu_items)){
                foreach ($menu_items as $menu_item) {
                    if ($menu_item->menu_item_parent == 0 && $menu_item->post_status == 'publish') {
                        $menu_array[$menu_item->ID] = $menu_item->title;
                    }
                }
            }
        }

        Musart_Options::add_field( array(
            'type' => 'select',
            'settings' => 'main_navigation_logo_position',
            'label' => esc_html__('Insert Logo After Menu Item', 'musart'),
            'section' => 'main_navigation',
            'default' => false,
            'priority' => 10,
            'choices' => $menu_array,
            'active_callback' => array(
                array(
                    'setting' => 'main_navigation_logo',
                    'operator' => '!=',
                    'value' => '',
                ),
                array(
                    'setting' => 'main_navigation_show',
                    'operator' => '==',
                    'value' => true,
                ),
                array(
                    'setting' => 'main_navigation_logo_area',
                    'operator' => '!=',
                    'value' => 'top',
                ),
            )
        ));
        Musart_Options::add_field( array(
            'type' => 'editor',
            'settings' => 'main_navigation_custom_content',
            'label' => esc_html__('Custom Content', 'musart'),
            'section' => 'main_navigation',
            'default' => '',
            'priority' => 10,
            'active_callback' => array(
                array(
                    'setting' => 'main_navigation_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'select',
            'settings' => 'main_navigation_custom_content_position',
            'label' => esc_html__('Content Position', 'musart'),
            'section' => 'main_navigation',
            'default' => 'before_icons',
            'priority' => 10,
            'choices' => array(
                'before_icons' => esc_attr__('Before Icons', 'musart'),
                'after_icons' => esc_attr__('After Icons', 'musart'),
                'before_menu' => esc_attr__('Before Menu', 'musart'),
                'after_menu' => esc_attr__('After Menu', 'musart'),
            ),
            'active_callback' => array(
                array(
                    'setting' => 'main_navigation_custom_content',
                    'operator' => '!=',
                    'value' => '',
                ),
                array(
                    'setting' => 'main_navigation_show',
                    'operator' => '==',
                    'value' => true,
                ),
            )
        ));
        /*
        For Mobile
        */
        Musart_Options::add_field( array(
            'type' => 'toggle',
            'settings' => 'main_navigation_mobile_show',
            'label' => esc_html__('Show', 'musart'),
            'section' => 'mobile_navigation',
            'default' => 'on',
            'priority' => 10,
        ));
        Musart_Options::add_field( array(
            'type' => 'image',
            'settings' => 'main_navigation_logo_mobile',
            'label' => esc_html__('Logo', 'musart'),
            'section' => 'mobile_navigation',
            'default' => get_template_directory_uri() . '/assets/images/logo-music-label-light.png',
            'priority' => 10,
            'active_callback' => array(
                array(
                    'setting' => 'main_navigation_mobile_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'slider',
            'settings' => 'main_navigation_logo_mobile_width',
            'label' => esc_attr__('Logo width', 'musart'),
            'section' => 'mobile_navigation',
            'default' => 90,
            'choices' => array(
                'min' => '20',
                'max' => '160',
                'step' => '1',
            ),
            'active_callback' => array(
                array(
                    'setting' => 'main_navigation_logo_mobile',
                    'operator' => '!=',
                    'value' => '',
                ),
                array(
                    'setting' => 'main_navigation_mobile_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'toggle',
            'settings' => 'mobile_navbar_light',
            'label' => esc_html__('Light Color', 'musart'),
            'section' => 'mobile_navigation',
            'default' => 'on',
            'priority' => 10,
            'active_callback' => array(
                array(
                    'setting' => 'main_navigation_mobile_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'toggle',
            'settings' => 'mobile_navbar_white_icon',
            'label' => esc_html__('Light Icon', 'musart'),
            'section' => 'mobile_navigation',
            'default' => 'off',
            'priority' => 10,
            'active_callback' => array(
                array(
                    'setting' => 'main_navigation_mobile_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'toggle',
            'settings' => 'mobile_navigation_overlay_content',
            'label' => esc_html__('Overlay Content', 'musart'),
            'section' => 'mobile_navigation',
            'default' => 'on',
            'priority' => 10,
            'active_callback' => array(
                array(
                    'setting' => 'main_navigation_mobile_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'toggle',
            'settings' => 'mobile_navigation_lg',
            'label' => esc_html__('Large Size', 'musart'),
            'section' => 'mobile_navigation',
            'default' => 'off',
            'priority' => 10,
            'active_callback' => array(
                array(
                    'setting' => 'main_navigation_mobile_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));

        Musart_Options::add_field( array(
            'type' => 'select',
            'settings' => 'mobile_navigation_align',
            'label' => esc_html__('Navbar Align', 'musart'),
            'section' => 'mobile_navigation',
            'default' => 'left',
            'priority' => 10,
            'choices' => array(
                'center' => esc_attr__('Center', 'musart'),
                'right' => esc_attr__('Right', 'musart'),
                'left' => esc_attr__('Left', 'musart')
            ),
            'active_callback' => array(
                array(
                    'setting' => 'main_navigation_mobile_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'select',
            'settings' => 'mobile_navigation_vertical_align',
            'label' => esc_html__('Vertical Align', 'musart'),
            'section' => 'mobile_navigation',
            'default' => 'top',
            'priority' => 10,
            'choices' => array(
                'center' => esc_attr__('Center', 'musart'),
                'top' => esc_attr__('Top', 'musart')
            ),
            'active_callback' => array(
                array(
                    'setting' => 'main_navigation_mobile_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        /*
        Side navigation
        */
        Musart_Options::add_field( array(
            'type' => 'toggle',
            'settings' => 'side_navigation_show',
            'label' => esc_html__('Show', 'musart'),
            'section' => 'side_navigation',
            'default' => 'off',
            'priority' => 10
        ));
        Musart_Options::add_field( array(
            'type' => 'toggle',
            'settings' => 'side_navigation_light',
            'label' => esc_html__('Light Color', 'musart'),
            'section' => 'side_navigation',
            'default' => 'on',
            'priority' => 10,
            'active_callback' => array(
                array(
                    'setting' => 'side_navigation_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'toggle',
            'settings' => 'side_navigation_white_icon',
            'label' => esc_html__('Light Icon', 'musart'),
            'section' => 'side_navigation',
            'description' => esc_html__('Work if not set main navigation panel or if offset main navigation panel to left', 'musart'),
            'default' => 'off',
            'priority' => 10,
            'active_callback' => array(
                array(
                    'setting' => 'side_navigation_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'toggle',
            'settings' => 'side_navigation_overlay_content',
            'label' => esc_html__('Overlay Content', 'musart'),
            'section' => 'side_navigation',
            'default' => 'on',
            'priority' => 10,
            'active_callback' => array(
                array(
                    'setting' => 'side_navigation_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'toggle',
            'settings' => 'side_navigation_lg',
            'label' => esc_html__('Large Size', 'musart'),
            'section' => 'side_navigation',
            'default' => 'on',
            'priority' => 10,
            'active_callback' => array(
                array(
                    'setting' => 'side_navigation_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'select',
            'settings' => 'side_navigation_align',
            'label' => esc_html__('Navbar Align', 'musart'),
            'section' => 'side_navigation',
            'default' => 'center',
            'priority' => 10,
            'choices' => array(
                'center' => esc_attr__('Center', 'musart'),
                'right' => esc_attr__('Right', 'musart'),
                'left' => esc_attr__('Left', 'musart')
            ),
            'active_callback' => array(
                array(
                    'setting' => 'side_navigation_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'select',
            'settings' => 'side_navigation_vertical_align',
            'label' => esc_html__('Vertical Align', 'musart'),
            'section' => 'side_navigation',
            'default' => 'center',
            'priority' => 10,
            'choices' => array(
                'center' => esc_attr__('Center', 'musart'),
                'top' => esc_attr__('Top', 'musart')
            ),
            'active_callback' => array(
                array(
                    'setting' => 'side_navigation_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'image',
            'settings' => 'side_navigation_logo',
            'label' => esc_html__('Logo', 'musart'),
            'section' => 'side_navigation',
            'default' => get_template_directory_uri() . '/assets/images/logo-music-label-light.png',
            'priority' => 10,
            'active_callback' => array(
                array(
                    'setting' => 'side_navigation_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'slider',
            'settings' => 'side_navigation_logo_width',
            'label' => esc_attr__('Logo width', 'musart'),
            'section' => 'side_navigation',
            'default' => 130,
            'choices' => array(
                'min' => '20',
                'max' => '300',
                'step' => '1',
            ),
            'active_callback' => array(
                array(
                    'setting' => 'side_navigation_logo',
                    'operator' => '!=',
                    'value' => '',
                ),
                array(
                    'setting' => 'side_navigation_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'image',
            'settings' => 'side_navigation_background_image',
            'label' => esc_attr__('Background Image', 'musart'),
            'section' => 'side_navigation',
            'priority' => 10,
            'active_callback' => array(
                array(
                    'setting' => 'side_navigation_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'repeater',
            'label' => esc_html__('Social', 'musart'),
            'section' => 'side_navigation',
            'priority' => 10,
            'settings' => 'side_navigation_social',
            'description' => sprintf(wp_kses(__('Enter icon class. You can use <a href="%s" target="_blank">"ioicons"</a> and <a href="%2s" target="_blank">"Font Awesome"</a> icons.', 'musart'), array('a' => array('href' => array(), 'target' => array()))), esc_url("http://ionicons.com/"), esc_url("http://fontawesome.io/icons/")),
            'default' => array(
                array(
                    'target' => '_blank',
                    'link_url' => 'https://themeforest.net/user/_nk/portfolio?ref=_nK',
                    'icon' => 'ion-social-twitter',
                ),
                array(
                    'target' => '_blank',
                    'link_url' => 'https://themeforest.net/user/_nk/portfolio?ref=_nK',
                    'icon' => 'ion-social-instagram-outline',
                ),
                array(
                    'target' => '_blank',
                    'link_url' => 'https://themeforest.net/user/_nk/portfolio?ref=_nK',
                    'icon' => 'ion-social-dribbble-outline',
                ),
                array(
                    'target' => '_blank',
                    'link_url' => 'https://themeforest.net/user/_nk/portfolio?ref=_nK',
                    'icon' => 'ion-social-pinterest',
                ),
            ),
            'fields' => array(
                'target' => array(
                    'type' => 'select',
                    'label' => esc_html__('Target', 'musart'),
                    'priority' => 10,
                    'choices' => array(
                        '_blank' => esc_attr__('Blank', 'musart'),
                        '_self' => esc_attr__('Self', 'musart'),
                        '_parent' => esc_attr__('Parent', 'musart'),
                        '_top' => esc_attr__('Top', 'musart')
                    ),
                ),
                'link_url' => array(
                    'type' => 'text',
                    'label' => esc_attr__('Link URL', 'musart'),
                ),
                'icon' => array(
                    'type' => 'text',
                    'label' => esc_html__('Icon', 'musart'),
                ),
            ),
            'active_callback' => array(
                array(
                    'setting' => 'side_navigation_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'editor',
            'settings' => 'side_navigation_text',
            'label' => esc_html__('Footer Text', 'musart'),
            'section' => 'side_navigation',
            'priority' => 10,
            'default' => '<a href="https://nkdev.info" target="_blank">nK</a> &copy; 2019. All rights reserved',
            'active_callback' => array(
                array(
                    'setting' => 'side_navigation_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        /*
        Background
        */
        Musart_Options::add_field( array(
            'type' => 'color',
            'settings' => 'background_color',
            'label' => esc_attr__('Background Color', 'musart'),
            'section' => 'title_tagline',
            'default' => '#1c1c1c',
            'priority' => 10,
            'choices'     => array(
                'alpha' => true,
            ),
            'output' => array(
                array(
                    'element' => 'body',
                    'property' => 'background-color',
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'toggle',
            'settings' => 'show_border',
            'label' => esc_html__('Show Border', 'musart'),
            'section' => 'background_page_border',
            'default' => false,
            'priority' => 10,
            'choices' => array(
                true => esc_attr__('on', 'musart'),
                false => esc_attr__('off', 'musart'),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'select',
            'settings' => 'size_border',
            'label' => esc_html__('Size Border', 'musart'),
            'section' => 'background_page_border',
            'default' => 'md',
            'priority' => 10,
            'choices' => array(
                false => esc_attr__('Default', 'musart'),
                'md' => esc_attr__('Mid Size', 'musart'),
                'sm' => esc_attr__('Small Size', 'musart'),
            ),
            'active_callback' => array(
                array(
                    'setting' => 'show_border',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'color',
            'settings' => 'background_border',
            'label' => esc_html__('Border color', 'musart'),
            'section' => 'background_page_border',
            'default' => '#fff',
            'choices'     => array(
                'alpha' => true,
            ),
            'priority' => 10,
            'output' => array(
                array(
                    'element' => '.nk-page-border .nk-page-border-t',
                    'property' => 'background-color',
                    'suffix' => '!important'
                ),
                array(
                    'element' => '.nk-page-border .nk-page-border-b',
                    'property' => 'background-color',
                    'suffix' => '!important'
                ),
                array(
                    'element' => '.nk-page-border .nk-page-border-l',
                    'property' => 'background-color',
                    'suffix' => '!important'
                ),
                array(
                    'element' => '.nk-page-border .nk-page-border-r',
                    'property' => 'background-color',
                    'suffix' => '!important'
                ),
            ),
            'active_callback' => array(
                array(
                    'setting' => 'show_border',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        /*
        Side Buttons
        */
        Musart_Options::add_field( array(
            'type' => 'toggle',
            'settings' => 'side_buttons_visible',
            'label' => esc_html__('Buttons Visible', 'musart'),
            'section' => 'side_buttons',
            'default' => 'off',
            'priority' => 10
        ));
        Musart_Options::add_field( array(
            'type' => 'toggle',
            'settings' => 'side_buttons_light',
            'label' => esc_html__('Light Buttons', 'musart'),
            'section' => 'side_buttons',
            'default' => 'off',
            'priority' => 10
        ));
        Musart_Options::add_field( array(
            'type' => 'toggle',
            'settings' => 'side_buttons_show_scroll_top',
            'label' => esc_html__('Scroll Top Button', 'musart'),
            'section' => 'side_buttons',
            'default' => 'on',
            'priority' => 10
        ));
        Musart_Options::add_field( array(
            'type' => 'toggle',
            'settings' => 'side_buttons_show_link_button',
            'label' => esc_html__('Link Button', 'musart'),
            'section' => 'side_buttons',
            'default' => 'off',
            'priority' => 10
        ));
        Musart_Options::add_field( array(
            'type' => 'text',
            'settings' => 'side_buttons_link_button',
            'label' => esc_html__('Link Button', 'musart'),
            'section' => 'side_buttons',
            'default' => '#',
            'priority' => 10,
            'active_callback' => array(
                array(
                    'setting' => 'side_buttons_show_link_button',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        /**
         * Typography
         */
        Musart_Options::add_field( array(
            'type' => 'typography',
            'settings' => 'typography_main_body',
            'label' => esc_attr__('Body', 'musart'),
            'section' => 'typography',
            'default' => array(
                'font-family' => 'Open Sans',
                'line-height' => '1.7',
                'letter-spacing' => '0rem'
            ),
            'priority' => 10,
            'output' => array(
                array(
                    'element' => 'body, .nk-counter-3 .nk-counter-title, .nk-sub-title, .nk-pricing-2 .nk-pricing-currency, .nk-pricing-2 .nk-pricing-period, .nk-pricing-3 .nk-pricing-currency, .nk-pricing-3 .nk-pricing-period',
                ),
            ),
            'transport' => 'auto'
        ));
        Musart_Options::add_field( array(
            'type' => 'typography',
            'settings' => 'typography_html',
            'label' => esc_attr__('HTML', 'musart'),
            'section' => 'typography',
            'default' => array(
                'font-size' => '15px'
            ),
            'priority' => 10,
            'output' => array(
                array(
                    'element' => 'html',
                ),
            ),
            'transport' => 'auto'
        ));
        Musart_Options::add_field( array(
            'type' => 'typography',
            'settings' => 'typography_titles',
            'label' => esc_attr__('Main Titles', 'musart'),
            'section' => 'typography',
            'default' => array(
                'font-family' => 'Montserrat',
                'variant' => '700'
            ),
            'priority' => 10,
            'output' => array(
                array(
                    'element' => 'h1, .h1, h2, .h2, h3, .h3, h4, .h4, h5, .h5, h6, .h6, .display-1, .display-2, .display-3, .display-4, .nk-forum-topic > li .nk-forum-topic-author-name, .nk-countdown > div > span, .nk-carousel-3 .nk-carousel-prev .nk-carousel-arrow-name, .nk-carousel-3 .nk-carousel-next .nk-carousel-arrow-name, .nk-carousel .nk-carousel-prev .nk-carousel-arrow-name, .nk-carousel .nk-carousel-next .nk-carousel-arrow-name, .nk-pricing .nk-pricing-price, .nk-dropcap-3, .nk-counter .nk-count, .nk-counter-2 .nk-count, .nk-counter-3 .nk-count'
                ),
            ),
            'transport' => 'auto'
        ));
        /**
         * Footer
         */
        Musart_Options::add_field( array(
            'type' => 'toggle',
            'settings' => 'footer_show',
            'label' => esc_html__('Show', 'musart'),
            'section' => 'footer',
            'default' => 'on',
            'priority' => 10,
        ));
        Musart_Options::add_field( array(
            'type' => 'color',
            'settings' => 'footer_background_color',
            'label' => esc_html__('Background Color', 'musart'),
            'section' => 'footer',
            'default' => '#262626',
            'priority' => 10,
            'choices'     => array(
                'alpha' => true,
            ),
            'transport' => 'auto',
            'output' => array(
                array(
                    'element' => '.nk-footer',
                    'property' => 'background-color',
                )
            ),
            'active_callback' => array(
                array(
                    'setting' => 'footer_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'editor',
            'settings' => 'footer_text',
            'label' => esc_html__('Text', 'musart'),
            'section' => 'footer',
            'default' => '<a href="https://nkdev.info/" target="_blank">nK</a> &copy; 2019. All rights reserved',
            'priority' => 10,
            'active_callback' => array(
                array(
                    'setting' => 'footer_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));

        /**
         * Single page. Header
         * show,
         * size,
         * parallax for background image,
         * opacity parallax for content,
         * boxed,
         * Background Image,
         * Back Title,
         * Title - in ACF!,
         * Sub Title,
         * Content
         * Video Link,
         * */
        Musart_Options::add_field( array(
            'type' => 'toggle',
            'settings' => 'single_page_header_show',
            'label' => esc_html__('Show', 'musart'),
            'section' => 'single_page_header',
            'default' => 'on',
            'priority' => 10
        ));
        Musart_Options::add_field( array(
            'type' => 'toggle',
            'settings' => 'single_page_header_show_title',
            'label' => esc_html__('Show Title', 'musart'),
            'section' => 'single_page_header',
            'default' => 'on',
            'priority' => 10,
        ));
        Musart_Options::add_field( array(
            'type' => 'select',
            'settings' => 'single_page_header_size',
            'label' => esc_html__('Size', 'musart'),
            'section' => 'single_page_header',
            'default' => false,
            'priority' => 10,
            'choices' => array(
                false => esc_attr__('Default', 'musart'),
                'sm' => esc_attr__('Small', 'musart'),
                'md' => esc_attr__('Middle', 'musart'),
                'lg' => esc_attr__('Large', 'musart'),
                'xl' => esc_attr__('X-Large', 'musart'),
                'full' => esc_attr__('Full', 'musart'),
            ),
            'active_callback' => array(
                array(
                    'setting' => 'single_page_header_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'toggle',
            'settings' => 'single_page_header_parallax',
            'label' => esc_html__('Parallax for Background Image', 'musart'),
            'section' => 'single_page_header',
            'default' => 'on',
            'priority' => 10,
            'active_callback' => array(
                array(
                    'setting' => 'single_page_header_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'toggle',
            'settings' => 'single_page_header_parallax_opacity',
            'label' => esc_html__('Opacity Parallax Content', 'musart'),
            'section' => 'single_page_header',
            'default' => 'on',
            'priority' => 10,
            'active_callback' => array(
                array(
                    'setting' => 'single_page_header_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'select',
            'settings' => 'single_page_header_type_image',
            'label' => esc_html__('Select Type of Background Image', 'musart'),
            'section' => 'single_page_header',
            'default' => 'featured',
            'priority' => 10,
            'choices' => array(
                false => esc_attr__('False', 'musart'),
                'featured' => esc_attr__('Featured', 'musart'),
                'custom' => esc_attr__('Custom', 'musart'),
            ),
            'active_callback' => array(
                array(
                    'setting' => 'single_page_header_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'image',
            'settings' => 'single_page_header_background_image',
            'label' => esc_html__('Background Image', 'musart'),
            'section' => 'single_page_header',
            'default' => get_template_directory_uri() . '/assets/images/default-banner.jpg',
            'priority' => 10,
            'active_callback' => array(
                array(
                    'setting' => 'single_page_header_show',
                    'operator' => '==',
                    'value' => true,
                ),
                array(
                    'setting' => 'single_page_header_type_image',
                    'operator' => '==',
                    'value' => 'custom',
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'slider',
            'settings' => 'single_page_header_background_image_opacity',
            'label' => esc_attr__('Opacity', 'musart'),
            'section' => 'single_page_header',
            'default' => 5,
            'priority' => 10,
            'choices' => array(
                'min' => '0',
                'max' => '10',
                'step' => '1',
            ),
            'active_callback' => array(
                array(
                    'setting' => 'single_page_header_type_image',
                    'operator' => '!=',
                    'value' => false,
                ),
                array(
                    'setting' => 'single_page_header_show',
                    'operator' => '==',
                    'value' => true,
                ),

            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'number',
            'settings' => 'single_page_header_title_padding_bottom',
            'label' => esc_attr__('Title Padding Bottom', 'musart'),
            'section' => 'single_page_header',
            'default' => 0,
            'priority' => 10,
            'choices' => array(
                'min' => '0',
                'max' => '500',
                'step' => '1',
            ),
            'active_callback' => array(
                array(
                    'setting' => 'single_page_header_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'select',
            'settings' => 'single_page_header_title_looks_like',
            'label' => esc_html__('Title Looks Like', 'musart'),
            'section' => 'single_page_header',
            'default' => '',
            'priority' => 10,
            'choices' => array(
                '' => esc_attr__('disabled', 'musart'),
                'h1' => esc_attr__('h1', 'musart'),
                'h2' => esc_attr__('h2', 'musart'),
                'h3' => esc_attr__('h3', 'musart'),
                'h4' => esc_attr__('h4', 'musart'),
                'h5' => esc_attr__('h5', 'musart'),
                'h6' => esc_attr__('h6', 'musart'),
                'display-1' => esc_attr__('display-1', 'musart'),
                'display-2' => esc_attr__('display-2', 'musart'),
                'display-3' => esc_attr__('display-3', 'musart'),
                'display-4' => esc_attr__('display-4', 'musart')
            ),
            'active_callback' => array(
                array(
                    'setting' => 'single_page_header_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'select',
            'settings' => 'single_page_header_title_align',
            'label' => esc_html__('Title Align', 'musart'),
            'section' => 'single_page_header',
            'default' => 'center',
            'priority' => 10,
            'choices' => array(
                'center' => esc_attr__('Center', 'musart'),
                'left' => esc_attr__('Left', 'musart'),
                'right' => esc_attr__('Right', 'musart'),
            ),
            'active_callback' => array(
                array(
                    'setting' => 'single_page_header_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'text',
            'settings' => 'single_page_header_back_title',
            'label' => esc_html__('Back Title', 'musart'),
            'section' => 'single_page_header',
            'default' => '',
            'priority' => 10,
            'active_callback' => array(
                array(
                    'setting' => 'single_page_header_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'slider',
            'settings' => 'single_page_header_back_title_opacity',
            'label' => esc_attr__('Back Title Opacity', 'musart'),
            'section' => 'single_page_header',
            'default' => 1,
            'priority' => 10,
            'choices' => array(
                'min' => '0',
                'max' => '10',
                'step' => '1',
            ),
            'active_callback' => array(
                array(
                    'setting' => 'single_page_header_back_title',
                    'operator' => '!=',
                    'value' => '',
                ),
                array(
                    'setting' => 'single_page_header_show',
                    'operator' => '==',
                    'value' => true,
                ),

            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'number',
            'settings' => 'single_page_header_back_title_padding_bottom',
            'label' => esc_attr__('Back Title Padding Bottom', 'musart'),
            'section' => 'single_page_header',
            'default' => 0,
            'priority' => 10,
            'choices' => array(
                'min' => '0',
                'max' => '500',
                'step' => '1',
            ),
            'active_callback' => array(
                array(
                    'setting' => 'single_page_header_back_title',
                    'operator' => '!=',
                    'value' => '',
                ),
                array(
                    'setting' => 'single_page_header_show',
                    'operator' => '==',
                    'value' => true,
                ),

            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'select',
            'settings' => 'single_page_header_back_title_align',
            'label' => esc_html__('Back Title Align', 'musart'),
            'section' => 'single_page_header',
            'default' => 'center',
            'priority' => 10,
            'choices' => array(
                'center' => esc_attr__('Center', 'musart'),
                'left' => esc_attr__('Left', 'musart'),
                'right' => esc_attr__('Right', 'musart'),
            ),
            'active_callback' => array(
                array(
                    'setting' => 'single_page_header_back_title',
                    'operator' => '!=',
                    'value' => '',
                ),
                array(
                    'setting' => 'single_page_header_show',
                    'operator' => '==',
                    'value' => true,
                ),

            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'text',
            'settings' => 'single_page_header_sub_title',
            'label' => esc_html__('Sub Title', 'musart'),
            'section' => 'single_page_header',
            'default' => '',
            'priority' => 10,
            'active_callback' => array(
                array(
                    'setting' => 'single_page_header_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'number',
            'settings' => 'single_page_header_sub_title_padding_bottom',
            'label' => esc_attr__('Sub Title Padding Bottom', 'musart'),
            'section' => 'single_page_header',
            'default' => 40,
            'priority' => 10,
            'choices' => array(
                'min' => '0',
                'max' => '500',
                'step' => '1',
            ),
            'active_callback' => array(
                array(
                    'setting' => 'single_page_header_sub_title',
                    'operator' => '!=',
                    'value' => '',
                ),
                array(
                    'setting' => 'single_page_header_show',
                    'operator' => '==',
                    'value' => true,
                ),

            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'select',
            'settings' => 'single_page_header_sub_title_align',
            'label' => esc_html__('Sub Title Align', 'musart'),
            'section' => 'single_page_header',
            'default' => 'center',
            'priority' => 10,
            'choices' => array(
                'center' => esc_attr__('Center', 'musart'),
                'left' => esc_attr__('Left', 'musart'),
                'right' => esc_attr__('Right', 'musart'),
            ),
            'active_callback' => array(
                array(
                    'setting' => 'single_page_header_sub_title',
                    'operator' => '!=',
                    'value' => '',
                ),
                array(
                    'setting' => 'single_page_header_show',
                    'operator' => '==',
                    'value' => true,
                ),

            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'editor',
            'settings' => 'single_page_header_content',
            'label' => esc_html__('Content', 'musart'),
            'section' => 'single_page_header',
            'default' => '',
            'priority' => 10,
            'active_callback' => array(
                array(
                    'setting' => 'single_page_header_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'text',
            'settings' => 'single_page_header_video_link',
            'label' => esc_html__('Video Link', 'musart'),
            'section' => 'single_page_header',
            'default' => '',
            'description' => esc_html__('Supported YouTube and Vimeo video link', 'musart'),
            'priority' => 10,
            'active_callback' => array(
                array(
                    'setting' => 'single_page_header_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'select',
            'settings' => 'single_page_header_video_style',
            'label' => esc_html__('Icon Video Style', 'musart'),
            'section' => 'single_page_header',
            'default' => false,
            'priority' => 10,
            'choices' => array(
                false => esc_attr__('Black', 'musart'),
                '2' => esc_attr__('Black 2', 'musart'),
                'light' => esc_attr__('Light', 'musart'),
                '2-light' => esc_attr__('Light 2', 'musart')
            ),
            'active_callback' => array(
                array(
                    'setting' => 'single_page_header_show',
                    'operator' => '==',
                    'value' => true,
                ),
                array(
                    'setting' => 'single_page_header_video_link',
                    'operator' => '!=',
                    'value' => '',
                ),
            ),
        ));
        /**
         * Single page. Sidebar
         * */
        Musart_Options::add_field( array(
            'type' => 'toggle',
            'settings' => 'sidebar_page_show',
            'label' => esc_html__('Show', 'musart'),
            'section' => 'single_page_sidebar',
            'default' => 'off',
            'priority' => 10,
        ));
        Musart_Options::add_field( array(
            'type' => 'select',
            'settings' => 'sidebar_page_list',
            'label' => esc_html__('Type', 'musart'),
            'section' => 'single_page_sidebar',
            'default' => 'single_page',
            'priority' => 10,
            'choices' => $sidebars,
            'active_callback' => array(
                array(
                    'setting' => 'sidebar_page_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'select',
            'settings' => 'sidebar_page_side',
            'label' => esc_html__('Side', 'musart'),
            'section' => 'single_page_sidebar',
            'default' => 'right',
            'priority' => 10,
            'choices' => array(
                'right' => esc_attr__('Right', 'musart'),
                'left' => esc_attr__('Left', 'musart'),
                'both' => esc_attr__('Both', 'musart'),
            ),
            'active_callback' => array(
                array(
                    'setting' => 'sidebar_page_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'select',
            'settings' => 'sidebar_page_additional_list',
            'label' => esc_html__('Type additional', 'musart'),
            'section' => 'single_page_sidebar',
            'default' => 'single_page',
            'priority' => 10,
            'choices' => $sidebars,
            'active_callback' => array(
                array(
                    'setting' => 'sidebar_page_show',
                    'operator' => '==',
                    'value' => true,
                ),
                array(
                    'setting' => 'sidebar_page_side',
                    'operator' => '==',
                    'value' => 'both',
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'toggle',
            'settings' => 'sidebar_page_sticky',
            'label' => esc_html__('Sticky', 'musart'),
            'section' => 'single_page_sidebar',
            'default' => 'on',
            'priority' => 10,
            'active_callback' => array(
                array(
                    'setting' => 'sidebar_page_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'color',
            'settings' => 'sidebar_single_page_background_color',
            'label' => esc_attr__('Background Color', 'musart'),
            'section' => 'single_page_sidebar',
            'default' => '#f7f7f7',
            'priority' => 10,
            'choices'     => array(
                'alpha' => true,
            ),
            'output' => array(
                array(
                    'element' => '.nk-sidebar.nk-sidebar-page:after',
                    'property' => 'background-color',
                ),
            ),
            'active_callback' => array(
                array(
                    'setting' => 'sidebar_page_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'color',
            'settings' => 'sidebar_single_page_text_color',
            'label' => esc_attr__('Text Color', 'musart'),
            'section' => 'single_page_sidebar',
            'default' => 'inherit',
            'priority' => 10,
            'choices'     => array(
                'alpha' => true,
            ),
            'output' => array(
                array(
                    'element' => '.nk-sidebar.nk-sidebar-page',
                    'property' => 'color',
                ),
            ),
            'active_callback' => array(
                array(
                    'setting' => 'sidebar_page_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        /**
         * Single page. Content
         * */
        Musart_Options::add_field( array(
            'type' => 'toggle',
            'settings' => 'single_page_content_show_title',
            'label' => esc_html__('Show Title', 'musart'),
            'section' => 'single_page_content',
            'default' => 'off',
            'priority' => 10,
        ));

        //Boxed for body tag
        Musart_Options::add_field( array(
            'type' => 'toggle',
            'settings' => 'single_page_boxed',
            'label' => esc_html__('Boxed Content', 'musart'),
            'section' => 'single_page_content',
            'default' => 'on',
            'priority' => 10,
        ));
        Musart_Options::add_field( array(
            'type' => 'toggle',
            'settings' => 'single_page_paddings',
            'label' => esc_html__('Top and Bottom paddings', 'musart'),
            'section' => 'single_page_content',
            'default' => 'on',
            'priority' => 10,
        ));
        /**
         * Single post. Content
         * */
        Musart_Options::add_field( array(
            'type' => 'select',
            'settings' => 'single_post_boxed',
            'label' => esc_html__('Boxed', 'musart'),
            'section' => 'single_post_content',
            'default' => 'true',
            'priority' => 10,
            'choices' => array(
                'true' => esc_attr__('Enabled', 'musart'),
                false => esc_attr__('Disabled', 'musart'),
                'narrow' => esc_attr__('Narrow', 'musart'),
            ),
        ));

        Musart_Options::add_field( array(
            'type' => 'toggle',
            'settings' => 'single_post_content_show_title',
            'label' => esc_html__('Show Title', 'musart'),
            'section' => 'single_post_content',
            'default' => 'off',
            'priority' => 10,
        ));
        Musart_Options::add_field( array(
            'type' => 'toggle',
            'settings' => 'single_post_adjacent_pagination',
            'label' => esc_html__('Adjacent Pagination', 'musart'),
            'section' => 'single_post_content',
            'default' => 'on',
            'priority' => 10,
        ));
        /**
         * Single post. Header
         * */
        Musart_Options::add_field( array(
            'type' => 'toggle',
            'settings' => 'single_post_header_show',
            'label' => esc_html__('Show header', 'musart'),
            'section' => 'single_post_header',
            'default' => 'on',
            'priority' => 10,
        ));
        Musart_Options::add_field( array(
            'type' => 'toggle',
            'settings' => 'single_post_header_show_title',
            'label' => esc_html__('Show Title', 'musart'),
            'section' => 'single_post_header',
            'default' => 'on',
            'priority' => 10,
        ));
        Musart_Options::add_field( array(
            'type' => 'number',
            'settings' => 'single_post_header_title_padding_bottom',
            'label' => esc_attr__('Title Padding Bottom', 'musart'),
            'section' => 'single_post_header',
            'default' => 0,
            'priority' => 10,
            'choices' => array(
                'min' => '0',
                'max' => '500',
                'step' => '1',
            ),
            'active_callback' => array(
                array(
                    'setting' => 'single_post_header_show_title',
                    'operator' => '==',
                    'value' => true,
                ),
                array(
                    'setting' => 'single_post_header_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'select',
            'settings' => 'single_post_header_title_looks_like',
            'label' => esc_html__('Title Looks Like', 'musart'),
            'section' => 'single_post_header',
            'default' => '',
            'priority' => 10,
            'choices' => array(
                '' => esc_attr__('disabled', 'musart'),
                'h1' => esc_attr__('h1', 'musart'),
                'h2' => esc_attr__('h2', 'musart'),
                'h3' => esc_attr__('h3', 'musart'),
                'h4' => esc_attr__('h4', 'musart'),
                'h5' => esc_attr__('h5', 'musart'),
                'h6' => esc_attr__('h6', 'musart'),
                'display-1' => esc_attr__('display-1', 'musart'),
                'display-2' => esc_attr__('display-2', 'musart'),
                'display-3' => esc_attr__('display-3', 'musart'),
                'display-4' => esc_attr__('display-4', 'musart')
            ),
            'active_callback' => array(
                array(
                    'setting' => 'single_post_header_show_title',
                    'operator' => '==',
                    'value' => true,
                ),
                array(
                    'setting' => 'single_post_header_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'select',
            'settings' => 'single_post_header_title_align',
            'label' => esc_html__('Title Align', 'musart'),
            'section' => 'single_post_header',
            'default' => 'center',
            'priority' => 10,
            'choices' => array(
                'center' => esc_attr__('Center', 'musart'),
                'left' => esc_attr__('Left', 'musart'),
                'right' => esc_attr__('Right', 'musart'),
            ),
            'active_callback' => array(
                array(
                    'setting' => 'single_post_header_show_title',
                    'operator' => '==',
                    'value' => true,
                ),
                array(
                    'setting' => 'single_post_header_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'select',
            'settings' => 'single_post_header_size',
            'label' => esc_html__('Size', 'musart'),
            'section' => 'single_post_header',
            'default' => false,
            'priority' => 10,
            'choices' => array(
                false => esc_attr__('Default', 'musart'),
                'sm' => esc_attr__('Small', 'musart'),
                'md' => esc_attr__('Middle', 'musart'),
                'lg' => esc_attr__('Large', 'musart'),
                'xl' => esc_attr__('X-Large', 'musart'),
                'full' => esc_attr__('Full', 'musart'),
            ),
            'active_callback' => array(
                array(
                    'setting' => 'single_post_header_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'toggle',
            'settings' => 'single_post_header_parallax',
            'label' => esc_html__('Parallax for Background Image', 'musart'),
            'section' => 'single_post_header',
            'default' => 'on',
            'priority' => 10,
            'active_callback' => array(
                array(
                    'setting' => 'single_post_header_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'toggle',
            'settings' => 'single_post_header_parallax_opacity',
            'label' => esc_html__('Opacity Parallax Content', 'musart'),
            'section' => 'single_post_header',
            'default' => 'on',
            'priority' => 10,
            'active_callback' => array(
                array(
                    'setting' => 'single_post_header_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'select',
            'settings' => 'single_post_header_type_image',
            'label' => esc_html__('Select Type of Background Image', 'musart'),
            'section' => 'single_post_header',
            'default' => 'featured',
            'priority' => 10,
            'choices' => array(
                false => esc_attr__('False', 'musart'),
                'featured' => esc_attr__('Featured', 'musart'),
                'custom' => esc_attr__('Custom', 'musart'),
            ),
            'active_callback' => array(
                array(
                    'setting' => 'single_post_header_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'image',
            'settings' => 'single_post_header_background_image',
            'label' => esc_html__('Background Image', 'musart'),
            'section' => 'single_post_header',
            'default' => get_template_directory_uri() . '/assets/images/default-banner.jpg',
            'priority' => 10,
            'active_callback' => array(
                array(
                    'setting' => 'single_post_header_show',
                    'operator' => '==',
                    'value' => true,
                ),
                array(
                    'setting' => 'single_post_header_type_image',
                    'operator' => '==',
                    'value' => 'custom',
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'slider',
            'settings' => 'single_post_header_background_image_opacity',
            'label' => esc_attr__('Opacity', 'musart'),
            'section' => 'single_post_header',
            'default' => 5,
            'priority' => 10,
            'choices' => array(
                'min' => '0',
                'max' => '10',
                'step' => '1',
            ),
            'active_callback' => array(
                array(
                    'setting' => 'single_post_header_type_image',
                    'operator' => '!=',
                    'value' => false,
                ),
                array(
                    'setting' => 'single_post_header_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        /**
         * Single post. Meta
         * */
        Musart_Options::add_field( array(
            'type' => 'toggle',
            'settings' => 'single_post_meta_show',
            'label' => esc_html__('Show Meta', 'musart'),
            'section' => 'single_post_meta',
            'default' => 'on',
            'priority' => 10,
        ));
        Musart_Options::add_field( array(
            'type' => 'toggle',
            'settings' => 'single_post_date_author_category_show',
            'label' => esc_html__('Show Date, Author, Category block', 'musart'),
            'section' => 'single_post_meta',
            'default' => 'on',
            'priority' => 10,
        ));
        Musart_Options::add_field( array(
            'type' => 'select',
            'settings' => 'single_post_date_author_category_area',
            'label' => esc_html__('Block Area', 'musart'),
            'section' => 'single_post_meta',
            'default' => 'header-middle',
            'priority' => 10,
            'choices' => array(
                'header-middle' => esc_attr__('Header. Middle', 'musart'),
                'header-bottom' => esc_attr__('Header. Bottom', 'musart'),
                'content-top' => esc_attr__('Content. Top', 'musart'),
                'content-after-format' => esc_attr__('After Format Content', 'musart'),
            ),
            'active_callback' => array(
                array(
                    'setting' => 'single_post_date_author_category_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'toggle',
            'settings' => 'single_post_meta_published_show',
            'label' => esc_html__('Show Meta Published', 'musart'),
            'section' => 'single_post_meta',
            'default' => 'on',
            'priority' => 10,
            'active_callback' => array(
                array(
                    'setting' => 'single_post_meta_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'toggle',
            'settings' => 'single_post_meta_categories_show',
            'label' => esc_html__('Show Meta Categories', 'musart'),
            'section' => 'single_post_meta',
            'default' => 'on',
            'priority' => 10,
            'active_callback' => array(
                array(
                    'setting' => 'single_post_meta_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'toggle',
            'settings' => 'single_post_meta_author_show',
            'label' => esc_html__('Show Meta Author', 'musart'),
            'section' => 'single_post_meta',
            'default' => 'on',
            'priority' => 10,
            'active_callback' => array(
                array(
                    'setting' => 'single_post_meta_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        /**
         * Single Post. Sidebar
         * */
        Musart_Options::add_field( array(
            'type' => 'toggle',
            'settings' => 'sidebar_post_show',
            'label' => esc_html__('Show', 'musart'),
            'section' => 'single_post_sidebar',
            'default' => 'on',
            'priority' => 10,
        ));
        Musart_Options::add_field( array(
            'type' => 'select',
            'settings' => 'sidebar_post_list',
            'label' => esc_html__('Type', 'musart'),
            'section' => 'single_post_sidebar',
            'default' => 'sidebar-post',
            'priority' => 10,
            'choices' => $sidebars,
            'active_callback' => array(
                array(
                    'setting' => 'sidebar_post_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'select',
            'settings' => 'sidebar_post_side',
            'label' => esc_html__('Side', 'musart'),
            'section' => 'single_post_sidebar',
            'default' => 'right',
            'priority' => 10,
            'choices' => array(
                'right' => esc_attr__('Right', 'musart'),
                'left' => esc_attr__('Left', 'musart'),
                'both' => esc_attr__('Both', 'musart'),
            ),
            'active_callback' => array(
                array(
                    'setting' => 'sidebar_post_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'select',
            'settings' => 'sidebar_post_additional_list',
            'label' => esc_html__('Type additional', 'musart'),
            'section' => 'single_post_sidebar',
            'default' => 'single_page',
            'priority' => 10,
            'choices' => $sidebars,
            'active_callback' => array(
                array(
                    'setting' => 'sidebar_post_show',
                    'operator' => '==',
                    'value' => true,
                ),
                array(
                    'setting' => 'sidebar_post_side',
                    'operator' => '==',
                    'value' => 'both',
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'toggle',
            'settings' => 'sidebar_post_sticky',
            'label' => esc_html__('Sticky', 'musart'),
            'section' => 'single_post_sidebar',
            'default' => 'on',
            'priority' => 10,
            'active_callback' => array(
                array(
                    'setting' => 'sidebar_post_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'color',
            'settings' => 'sidebar_post_background_color',
            'label' => esc_attr__('Background Color', 'musart'),
            'section' => 'single_post_sidebar',
            'default' => '#f7f7f7',
            'priority' => 10,
            'choices'     => array(
                'alpha' => true,
            ),
            'output' => array(
                array(
                    'element' => '.nk-sidebar.nk-sidebar-post:after',
                    'property' => 'background-color',
                ),
            ),
            'active_callback' => array(
                array(
                    'setting' => 'sidebar_post_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'color',
            'settings' => 'sidebar_post_text_color',
            'label' => esc_attr__('Text Color', 'musart'),
            'section' => 'single_post_sidebar',
            'default' => 'inherit',
            'priority' => 10,
            'choices'     => array(
                'alpha' => true,
            ),
            'output' => array(
                array(
                    'element' => '.nk-sidebar.nk-sidebar-post',
                    'property' => 'color',
                ),
            ),
            'active_callback' => array(
                array(
                    'setting' => 'sidebar_post_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        /**
         * Custom posts function for init kirki standard fields
         * */
        kirki_initial_custom_post(
            array(
                'event',
                'playlist',
            )
        );
        /**
         *
         * Instagram
         */
        Musart_Options::add_section('musart_instagram', array(
            'title' => esc_html__('Instagram', 'musart'),
            'priority' => 12,
            'capability' => 'edit_theme_options',
            'icon' => 'fa fa-instagram'
        ));
        $get_token_url = 'https://instagram.com/oauth/authorize/?client_id=50ab03ef9bce4dac96349824154d1833&redirect_uri=http://instagram-api.nkdev.info?return_uri=' . admin_url('customize.php?autofocus[section]=musart_instagram') . '&response_type=token';
        Musart_Options::add_field( array(
            'type' => 'custom',
            'settings' => 'instagram_access_token_btn',
            'label' => esc_html__('Get Access Token', 'musart'),
            'section' => 'musart_instagram',
            'default' => '<a href="' . esc_url($get_token_url) . '" class="button button-hero button-primary">Log In and get Access Token</a>',
            'priority' => 10,
        ));
        Musart_Options::add_field( array(
            'type' => 'text',
            'settings' => 'instagram_access_token',
            'label' => esc_html__('Access Token', 'musart'),
            'section' => 'musart_instagram',
            'default' => '',
            'priority' => 10
        ));
        Musart_Options::add_field( array(
            'type' => 'text',
            'settings' => 'instagram_user_id',
            'label' => esc_html__('User ID', 'musart'),
            'description' => sprintf(wp_kses(__('Note that User ID corresponds to your Instagram <strong>account ID (eg: 4385108)</strong>, not your username. <br><br> If you do not know your account ID, Google <a href="%s" target="_blank">"What is my Instagram account ID?"</a>. There are several free tools available online that will look it up for you.', 'musart'), array('a' => array('href' => array()), 'strong' => array(), 'br' => array())), esc_url("https://google.com/search?q=What%20is%20my%20Instagram%20account%20ID%3F")),
            'section' => 'musart_instagram',
            'default' => '',
            'priority' => 10
        ));
        Musart_Options::add_field( array(
            'type' => 'text',
            'settings' => 'instagram_cachetime',
            'label' => esc_html__('Cache Time [seconds]', 'musart'),
            'section' => 'musart_instagram',
            'default' => '3600',
            'priority' => 10
        ));

        add_action('customize_controls_print_footer_scripts', 'musart_get_instagram_access_token_script', 20);
        if (!function_exists('musart_get_instagram_access_token_script')) :
            function musart_get_instagram_access_token_script()
            {
                ?>
                <script>
                    if ( typeof wp !== 'undefined' && wp.customize ) {
                        wp.customize( 'instagram_access_token', 'instagram_user_id', function( instagram_access_token, instagram_user_id ) {
                            var token = window.location.hash.replace('#access_token=', '');
                            var isValidToken = /#access_token=/g.test(window.location.hash);
                            var isDifferentValue = instagram_access_token.get() !== token;

                            if (isValidToken && isDifferentValue) {
                                var userID = token.split('.')[0];

                                instagram_access_token.set( token );
                                if ( userID ) {
                                    instagram_user_id.set( userID );
                                }
                            }
                        } );
                    }
                </script>
                <?php
            }
        endif;
        /**
         *
         * Twitter
         */
        Musart_Options::add_section('musart_twitter', array(
            'title' => esc_html__('Twitter', 'musart'),
            'priority' => 12,
            'capability' => 'edit_theme_options',
            'icon' => 'fa fa-twitter'
        ));
        Musart_Options::add_field( array(
            'type' => 'custom',
            'settings' => 'twitter_custom_text',
            'label' => sprintf(wp_kses(__('How to create Twitter API key you can read here (or use google): <a href="%s" target="_blank">%s</a>', 'musart'), array('a' => array('href' => array(), 'target' => array()))), esc_url("http://www.gabfirethemes.com/create-twitter-api-key/"), esc_url("http://www.gabfirethemes.com/create-twitter-api-key/")),
            'section' => 'musart_twitter',
            'default' => '',
            'priority' => 10,
        ));
        Musart_Options::add_field( array(
            'type' => 'text',
            'settings' => 'twitter_consumer_key',
            'label' => esc_html__('Consumer Key', 'musart'),
            'section' => 'musart_twitter',
            'default' => '',
            'priority' => 10
        ));
        Musart_Options::add_field( array(
            'type' => 'text',
            'settings' => 'twitter_consumer_secret',
            'label' => esc_html__('Consumer Secret', 'musart'),
            'section' => 'musart_twitter',
            'default' => '',
            'priority' => 10
        ));
        Musart_Options::add_field( array(
            'type' => 'text',
            'settings' => 'twitter_access_token',
            'label' => esc_html__('Access Token', 'musart'),
            'section' => 'musart_twitter',
            'default' => '',
            'priority' => 10
        ));
        Musart_Options::add_field( array(
            'type' => 'text',
            'settings' => 'twitter_access_token_secret',
            'label' => esc_html__('Access Token Secret', 'musart'),
            'section' => 'musart_twitter',
            'default' => '',
            'priority' => 10
        ));
        Musart_Options::add_field( array(
            'type' => 'text',
            'settings' => 'twitter_cache_time',
            'label' => esc_html__('Cache Time [seconds]', 'musart'),
            'section' => 'musart_twitter',
            'default' => '3',
            'priority' => 10
        ));
        Musart_Options::add_field( array(
            'type' => 'toggle',
            'settings' => 'twitter_show_replies',
            'label' => esc_html__('Show Replies', 'musart'),
            'section' => 'musart_twitter',
            'default' => 'off',
            'priority' => 10,
        ));
        /**
         * Not Found page
         **/
        Musart_Options::add_field( array(
            'type' => 'image',
            'settings' => 'not_found_image',
            'label' => esc_html__('Background Image', 'musart'),
            'section' => 'not_found_page',
            'default' => get_template_directory_uri() . '/assets/images/default-banner.jpg',
            'priority' => 10,
        ));
        Musart_Options::add_field( array(
            'type' => 'toggle',
            'settings' => 'not_found_show_text',
            'label' => esc_html__('Show Text', 'musart'),
            'section' => 'not_found_page',
            'default' => 'on',
            'priority' => 10,
        ));
        Musart_Options::add_field( array(
            'type' => 'toggle',
            'settings' => 'not_found_show_home_button',
            'label' => esc_html__('Show Home Button', 'musart'),
            'section' => 'not_found_page',
            'default' => 'on',
            'priority' => 10,
        ));
        /**
         * Archive page
         **/
        Musart_Options::add_field( array(
            'type' => 'select',
            'settings' => 'archive_pagination',
            'label' => esc_html__('Pagination', 'musart'),
            'section' => 'archive_content',
            'default' => 'load_more',
            'priority' => 10,
            'choices' => array(
                false => esc_html__("No Pagination", 'musart'),
                true => esc_html__("Simple Pagination", 'musart'),
                'load_more' => esc_html__("Load More button", 'musart'),
                'infinite' => esc_html__("Infinite Scroll", 'musart'),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'toggle',
            'settings' => 'archive_show_title',
            'label' => esc_html__('Show Title', 'musart'),
            'section' => 'archive_content',
            'default' => 'off',
            'priority' => 10,
        ));
        Musart_Options::add_field( array(
            'type' => 'toggle',
            'settings' => 'archive_boxed',
            'label' => esc_html__('Boxed Content', 'musart'),
            'section' => 'archive_content',
            'default' => 'on',
            'priority' => 10,
        ));
        //for posts list
        Musart_Options::add_field( array(
            'type' => 'select',
            'settings' => 'archive_list_style_content',
            'label' => esc_html__('Blog List Style', 'musart'),
            'section' => 'archive_content',
            'default' => 'classic',
            'priority' => 10,
            'choices' => array(
                'classic' => esc_attr__('Classic', 'musart'),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'slider',
            'settings' => 'archive_list_columns_content',
            'label' => esc_attr__('Number of Columns', 'musart'),
            'section' => 'archive_content',
            'default' => 1,
            'priority' => 10,
            'choices' => array(
                'min' => 1,
                'max' => 3,
                'step' => 1,
            ),
            'active_callback' => array(
                array(
                    'setting' => 'archive_list_style_content',
                    'operator' => '!=',
                    'value' => 'list',
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'select',
            'settings' => 'archive_preview_description_type_content',
            'label' => esc_html__('Preview Description Type', 'musart'),
            'section' => 'archive_content',
            'default' => 'excerpt',
            'priority' => 10,
            'choices' => array(
                'false' => esc_attr__('Disabled', 'musart'),
                'excerpt' => esc_attr__('Excerpt', 'musart'),
                'more' => esc_attr__('Use more tag', 'musart')
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'number',
            'settings' => 'archive_preview_description_trim_cnt',
            'label' => esc_html__('Cut in the number of words', 'musart'),
            'section' => 'archive_content',
            'default' => 50,
            'priority' => 10,
            'choices' => array(
                'min' => 0,
                'max' => 200,
                'step' => 1,
            ),
            'active_callback' => array(
                array(
                    'setting' => 'archive_preview_description_type_content',
                    'operator' => '==',
                    'value' => 'excerpt',
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'toggle',
            'settings' => 'archive_simple_view',
            'label' => esc_html__('Simple View', 'musart'),
            'section' => 'archive_content',
            'default' => 'off',
            'priority' => 10,
            'active_callback' => array(
                array(
                    'setting' => 'archive_list_style_content',
                    'operator' => '==',
                    'value' => 'classic',
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'toggle',
            'settings' => 'archive_show_continue_button',
            'label' => esc_html__('Show Continue Button', 'musart'),
            'section' => 'archive_content',
            'default' => 'off',
            'priority' => 10,
        ));
        /**
         * Archive page. Header
         **/
        Musart_Options::add_field( array(
            'type' => 'toggle',
            'settings' => 'archive_header_show',
            'label' => esc_html__('Show', 'musart'),
            'section' => 'archive_header',
            'default' => 'on',
            'priority' => 10
        ));
        Musart_Options::add_field( array(
            'type' => 'toggle',
            'settings' => 'archive_header_show_title',
            'label' => esc_html__('Show Title', 'musart'),
            'section' => 'archive_header',
            'default' => 'on',
            'priority' => 10,
        ));
        Musart_Options::add_field( array(
            'type' => 'number',
            'settings' => 'archive_header_title_padding_bottom',
            'label' => esc_attr__('Title Padding Bottom', 'musart'),
            'section' => 'archive_header',
            'default' => 0,
            'priority' => 10,
            'choices' => array(
                'min' => '0',
                'max' => '500',
                'step' => '1',
            ),
            'active_callback' => array(
                array(
                    'setting' => 'archive_header_show_title',
                    'operator' => '==',
                    'value' => true,
                ),
                array(
                    'setting' => 'archive_header_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'select',
            'settings' => 'archive_header_title_looks_like',
            'label' => esc_html__('Title Looks Like', 'musart'),
            'section' => 'archive_header',
            'default' => '',
            'priority' => 10,
            'choices' => array(
                '' => esc_attr__('disabled', 'musart'),
                'h1' => esc_attr__('h1', 'musart'),
                'h2' => esc_attr__('h2', 'musart'),
                'h3' => esc_attr__('h3', 'musart'),
                'h4' => esc_attr__('h4', 'musart'),
                'h5' => esc_attr__('h5', 'musart'),
                'h6' => esc_attr__('h6', 'musart'),
                'display-1' => esc_attr__('display-1', 'musart'),
                'display-2' => esc_attr__('display-2', 'musart'),
                'display-3' => esc_attr__('display-3', 'musart'),
                'display-4' => esc_attr__('display-4', 'musart')
            ),
            'active_callback' => array(
                array(
                    'setting' => 'archive_header_show_title',
                    'operator' => '==',
                    'value' => true,
                ),
                array(
                    'setting' => 'archive_header_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'select',
            'settings' => 'archive_header_title_align',
            'label' => esc_html__('Title Align', 'musart'),
            'section' => 'archive_header',
            'default' => 'center',
            'priority' => 10,
            'choices' => array(
                'center' => esc_attr__('Center', 'musart'),
                'left' => esc_attr__('Left', 'musart'),
                'right' => esc_attr__('Right', 'musart'),
            ),
            'active_callback' => array(
                array(
                    'setting' => 'archive_header_show_title',
                    'operator' => '==',
                    'value' => true,
                ),
                array(
                    'setting' => 'archive_header_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'select',
            'settings' => 'archive_header_size',
            'label' => esc_html__('Size', 'musart'),
            'section' => 'archive_header',
            'default' => false,
            'priority' => 10,
            'choices' => array(
                false => esc_attr__('Default', 'musart'),
                'sm' => esc_attr__('Small', 'musart'),
                'md' => esc_attr__('Middle', 'musart'),
                'lg' => esc_attr__('Large', 'musart'),
                'xl' => esc_attr__('X-Large', 'musart'),
                'full' => esc_attr__('Full', 'musart'),
            ),
            'active_callback' => array(
                array(
                    'setting' => 'archive_header_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'toggle',
            'settings' => 'archive_header_parallax',
            'label' => esc_html__('Parallax for Background Image', 'musart'),
            'section' => 'archive_header',
            'default' => 'on',
            'priority' => 10,
            'active_callback' => array(
                array(
                    'setting' => 'archive_header_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'toggle',
            'settings' => 'archive_header_parallax_opacity',
            'label' => esc_html__('Opacity Parallax Content', 'musart'),
            'section' => 'archive_header',
            'default' => 'on',
            'priority' => 10,
            'active_callback' => array(
                array(
                    'setting' => 'archive_header_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'image',
            'settings' => 'archive_header_background_image',
            'label' => esc_html__('Background Image', 'musart'),
            'section' => 'archive_header',
            'default' => get_template_directory_uri() . '/assets/images/default-banner.jpg',
            'priority' => 10,
            'active_callback' => array(
                array(
                    'setting' => 'archive_header_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'slider',
            'settings' => 'archive_header_background_image_opacity',
            'label' => esc_attr__('Opacity', 'musart'),
            'section' => 'archive_header',
            'default' => 5,
            'priority' => 10,
            'choices' => array(
                'min' => '0',
                'max' => '10',
                'step' => '1',
            ),
            'active_callback' => array(
                array(
                    'setting' => 'archive_header_show',
                    'operator' => '==',
                    'value' => true,
                ),
                array(
                    'setting' => 'archive_header_background_image',
                    'operator' => '!=',
                    'value' => '',
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'text',
            'settings' => 'archive_header_back_title',
            'label' => esc_html__('Back Title', 'musart'),
            'section' => 'archive_header',
            'default' => '',
            'priority' => 10,
            'active_callback' => array(
                array(
                    'setting' => 'archive_header_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'slider',
            'settings' => 'archive_header_back_title_opacity',
            'label' => esc_attr__('Back Title Opacity', 'musart'),
            'section' => 'archive_header',
            'default' => 1,
            'priority' => 10,
            'choices' => array(
                'min' => '0',
                'max' => '10',
                'step' => '1',
            ),
            'active_callback' => array(
                array(
                    'setting' => 'archive_header_back_title',
                    'operator' => '!=',
                    'value' => '',
                ),
                array(
                    'setting' => 'archive_header_show',
                    'operator' => '==',
                    'value' => true,
                ),

            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'number',
            'settings' => 'archive_header_back_title_padding_bottom',
            'label' => esc_attr__('Back Title Padding Bottom', 'musart'),
            'section' => 'archive_header',
            'default' => 0,
            'priority' => 10,
            'choices' => array(
                'min' => '0',
                'max' => '500',
                'step' => '1',
            ),
            'active_callback' => array(
                array(
                    'setting' => 'archive_header_back_title',
                    'operator' => '!=',
                    'value' => '',
                ),
                array(
                    'setting' => 'archive_header_show',
                    'operator' => '==',
                    'value' => true,
                ),

            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'select',
            'settings' => 'archive_header_back_title_align',
            'label' => esc_html__('Back Title Align', 'musart'),
            'section' => 'archive_header',
            'default' => 'center',
            'priority' => 10,
            'choices' => array(
                'center' => esc_attr__('Center', 'musart'),
                'left' => esc_attr__('Left', 'musart'),
                'right' => esc_attr__('Right', 'musart'),
            ),
            'active_callback' => array(
                array(
                    'setting' => 'archive_header_back_title',
                    'operator' => '!=',
                    'value' => '',
                ),
                array(
                    'setting' => 'archive_header_show',
                    'operator' => '==',
                    'value' => true,
                ),

            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'text',
            'settings' => 'archive_header_sub_title',
            'label' => esc_html__('Sub Title', 'musart'),
            'section' => 'archive_header',
            'default' => '',
            'priority' => 10,
            'active_callback' => array(
                array(
                    'setting' => 'archive_header_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'number',
            'settings' => 'archive_header_sub_title_padding_bottom',
            'label' => esc_attr__('Sub Title Padding Bottom', 'musart'),
            'section' => 'archive_header',
            'default' => 40,
            'priority' => 10,
            'choices' => array(
                'min' => '0',
                'max' => '500',
                'step' => '1',
            ),
            'active_callback' => array(
                array(
                    'setting' => 'archive_header_sub_title',
                    'operator' => '!=',
                    'value' => '',
                ),
                array(
                    'setting' => 'archive_header_show',
                    'operator' => '==',
                    'value' => true,
                ),

            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'select',
            'settings' => 'archive_header_sub_title_align',
            'label' => esc_html__('Sub Title Align', 'musart'),
            'section' => 'archive_header',
            'default' => 'center',
            'priority' => 10,
            'choices' => array(
                'center' => esc_attr__('Center', 'musart'),
                'left' => esc_attr__('Left', 'musart'),
                'right' => esc_attr__('Right', 'musart'),
            ),
            'active_callback' => array(
                array(
                    'setting' => 'archive_header_sub_title',
                    'operator' => '!=',
                    'value' => '',
                ),
                array(
                    'setting' => 'archive_header_show',
                    'operator' => '==',
                    'value' => true,
                ),

            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'editor',
            'settings' => 'archive_header_content',
            'label' => esc_html__('Content', 'musart'),
            'section' => 'archive_header',
            'default' => '',
            'priority' => 10,
            'active_callback' => array(
                array(
                    'setting' => 'archive_header_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'text',
            'settings' => 'archive_header_video_link',
            'label' => esc_html__('Video Link', 'musart'),
            'section' => 'archive_header',
            'description' => esc_html__('Supported YouTube and Vimeo video link', 'musart'),
            'default' => '',
            'priority' => 10,
            'active_callback' => array(
                array(
                    'setting' => 'archive_header_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'select',
            'settings' => 'archive_header_video_style',
            'label' => esc_html__('Icon Video Style', 'musart'),
            'section' => 'archive_header',
            'default' => false,
            'priority' => 10,
            'choices' => array(
                false => esc_attr__('Black', 'musart'),
                '2' => esc_attr__('Black 2', 'musart'),
                'light' => esc_attr__('Light', 'musart'),
                '2-light' => esc_attr__('Light 2', 'musart')
            ),
            'active_callback' => array(
                array(
                    'setting' => 'archive_header_show',
                    'operator' => '==',
                    'value' => true,
                ),
                array(
                    'setting' => 'archive_header_video_link',
                    'operator' => '!=',
                    'value' => '',
                ),
            ),
        ));
        /**
         * Search page
         **/
        Musart_Options::add_field( array(
            'type' => 'select',
            'settings' => 'search_pagination',
            'label' => esc_html__('Pagination', 'musart'),
            'section' => 'search_content',
            'default' => 'load_more',
            'priority' => 10,
            'choices' => array(
                false => esc_html__("No Pagination", 'musart'),
                true => esc_html__("Simple Pagination", 'musart'),
                'load_more' => esc_html__("Load More button", 'musart'),
                'infinite' => esc_html__("Infinite Scroll", 'musart'),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'toggle',
            'settings' => 'search_show_title',
            'label' => esc_html__('Show Title', 'musart'),
            'section' => 'search_content',
            'default' => 'off',
            'priority' => 10,
        ));
        Musart_Options::add_field( array(
            'type' => 'toggle',
            'settings' => 'search_boxed',
            'label' => esc_html__('Boxed', 'musart'),
            'section' => 'search_content',
            'default' => 'on',
            'priority' => 10,
        ));
        //for posts list
        Musart_Options::add_field( array(
            'type' => 'select',
            'settings' => 'search_list_style_content',
            'label' => esc_html__('Blog List Style', 'musart'),
            'section' => 'search_content',
            'default' => 'classic',
            'priority' => 10,
            'choices' => array(
                'classic' => esc_attr__('Classic', 'musart'),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'slider',
            'settings' => 'search_list_columns_content',
            'label' => esc_attr__('Number of Columns', 'musart'),
            'section' => 'search_content',
            'default' => 1,
            'priority' => 10,
            'choices' => array(
                'min' => 1,
                'max' => 3,
                'step' => 1,
            ),
            'active_callback' => array(
                array(
                    'setting' => 'search_list_style_content',
                    'operator' => '==',
                    'value' => 'classic',
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'select',
            'settings' => 'search_preview_description_type_content',
            'label' => esc_html__('Preview Description Type', 'musart'),
            'section' => 'search_content',
            'default' => 'excerpt',
            'priority' => 10,
            'choices' => array(
                'false' => esc_attr__('Disabled', 'musart'),
                'excerpt' => esc_attr__('Excerpt', 'musart'),
                'more' => esc_attr__('Use more tag', 'musart')
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'number',
            'settings' => 'search_preview_description_trim_cnt',
            'label' => esc_html__('Cut in the number of words', 'musart'),
            'section' => 'search_content',
            'default' => 50,
            'priority' => 10,
            'choices' => array(
                'min' => 0,
                'max' => 200,
                'step' => 1,
            ),
            'active_callback' => array(
                array(
                    'setting' => 'search_preview_description_type_content',
                    'operator' => '==',
                    'value' => 'excerpt',
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'toggle',
            'settings' => 'search_simple_view',
            'label' => esc_html__('Simple View', 'musart'),
            'section' => 'search_content',
            'default' => 'off',
            'priority' => 10,
            'active_callback' => array(
                array(
                    'setting' => 'search_list_style_content',
                    'operator' => '==',
                    'value' => 'classic',
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'toggle',
            'settings' => 'search_show_continue_button',
            'label' => esc_html__('Show Continue Button', 'musart'),
            'section' => 'search_content',
            'default' => 'off',
            'priority' => 10,
        ));

        /**
         * Search page. Header
         **/
        Musart_Options::add_field( array(
            'type' => 'toggle',
            'settings' => 'search_header_show',
            'label' => esc_html__('Show', 'musart'),
            'section' => 'search_header',
            'default' => 'on',
            'priority' => 10
        ));
        Musart_Options::add_field( array(
            'type' => 'toggle',
            'settings' => 'search_header_show_title',
            'label' => esc_html__('Show Title', 'musart'),
            'section' => 'search_header',
            'default' => 'on',
            'priority' => 10,
        ));
        Musart_Options::add_field( array(
            'type' => 'number',
            'settings' => 'search_header_title_padding_bottom',
            'label' => esc_attr__('Title Padding Bottom', 'musart'),
            'section' => 'search_header',
            'default' => 0,
            'priority' => 10,
            'choices' => array(
                'min' => '0',
                'max' => '500',
                'step' => '1',
            ),
            'active_callback' => array(
                array(
                    'setting' => 'search_header_show_title',
                    'operator' => '==',
                    'value' => true,
                ),
                array(
                    'setting' => 'search_header_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'select',
            'settings' => 'search_header_title_looks_like',
            'label' => esc_html__('Title Looks Like', 'musart'),
            'section' => 'search_header',
            'default' => '',
            'priority' => 10,
            'choices' => array(
                '' => esc_attr__('disabled', 'musart'),
                'h1' => esc_attr__('h1', 'musart'),
                'h2' => esc_attr__('h2', 'musart'),
                'h3' => esc_attr__('h3', 'musart'),
                'h4' => esc_attr__('h4', 'musart'),
                'h5' => esc_attr__('h5', 'musart'),
                'h6' => esc_attr__('h6', 'musart'),
                'display-1' => esc_attr__('display-1', 'musart'),
                'display-2' => esc_attr__('display-2', 'musart'),
                'display-3' => esc_attr__('display-3', 'musart'),
                'display-4' => esc_attr__('display-4', 'musart')
            ),
            'active_callback' => array(
                array(
                    'setting' => 'search_header_show_title',
                    'operator' => '==',
                    'value' => true,
                ),
                array(
                    'setting' => 'search_header_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'select',
            'settings' => 'search_header_title_align',
            'label' => esc_html__('Title Align', 'musart'),
            'section' => 'search_header',
            'default' => 'center',
            'priority' => 10,
            'choices' => array(
                'center' => esc_attr__('Center', 'musart'),
                'left' => esc_attr__('Left', 'musart'),
                'right' => esc_attr__('Right', 'musart'),
            ),
            'active_callback' => array(
                array(
                    'setting' => 'search_header_show_title',
                    'operator' => '==',
                    'value' => true,
                ),
                array(
                    'setting' => 'search_header_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'select',
            'settings' => 'search_header_size',
            'label' => esc_html__('Size', 'musart'),
            'section' => 'search_header',
            'default' => false,
            'priority' => 10,
            'choices' => array(
                false => esc_attr__('Default', 'musart'),
                'sm' => esc_attr__('Small', 'musart'),
                'md' => esc_attr__('Middle', 'musart'),
                'lg' => esc_attr__('Large', 'musart'),
                'xl' => esc_attr__('X-Large', 'musart'),
                'full' => esc_attr__('Full', 'musart'),
            ),
            'active_callback' => array(
                array(
                    'setting' => 'search_header_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'toggle',
            'settings' => 'search_header_parallax',
            'label' => esc_html__('Parallax for Background Image', 'musart'),
            'section' => 'search_header',
            'default' => 'on',
            'priority' => 10,
            'active_callback' => array(
                array(
                    'setting' => 'search_header_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'toggle',
            'settings' => 'search_header_parallax_opacity',
            'label' => esc_html__('Opacity Parallax Content', 'musart'),
            'section' => 'search_header',
            'default' => 'on',
            'priority' => 10,
            'active_callback' => array(
                array(
                    'setting' => 'search_header_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'image',
            'settings' => 'search_header_background_image',
            'label' => esc_html__('Background Image', 'musart'),
            'section' => 'search_header',
            'default' => get_template_directory_uri() . '/assets/images/default-banner.jpg',
            'priority' => 10,
            'active_callback' => array(
                array(
                    'setting' => 'search_header_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'slider',
            'settings' => 'search_header_background_image_opacity',
            'label' => esc_attr__('Opacity', 'musart'),
            'section' => 'search_header',
            'default' => 5,
            'priority' => 10,
            'choices' => array(
                'min' => '0',
                'max' => '10',
                'step' => '1',
            ),
            'active_callback' => array(
                array(
                    'setting' => 'search_header_show',
                    'operator' => '==',
                    'value' => true,
                ),
                array(
                    'setting' => 'search_header_background_image',
                    'operator' => '!=',
                    'value' => '',
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'text',
            'settings' => 'search_header_back_title',
            'label' => esc_html__('Back Title', 'musart'),
            'section' => 'search_header',
            'default' => '',
            'priority' => 10,
            'active_callback' => array(
                array(
                    'setting' => 'search_header_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'slider',
            'settings' => 'search_header_back_title_opacity',
            'label' => esc_attr__('Back Title Opacity', 'musart'),
            'section' => 'search_header',
            'default' => 1,
            'priority' => 10,
            'choices' => array(
                'min' => '0',
                'max' => '10',
                'step' => '1',
            ),
            'active_callback' => array(
                array(
                    'setting' => 'search_header_back_title',
                    'operator' => '!=',
                    'value' => '',
                ),
                array(
                    'setting' => 'search_header_show',
                    'operator' => '==',
                    'value' => true,
                ),

            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'number',
            'settings' => 'search_header_back_title_padding_bottom',
            'label' => esc_attr__('Back Title Padding Bottom', 'musart'),
            'section' => 'search_header',
            'default' => 0,
            'priority' => 10,
            'choices' => array(
                'min' => '0',
                'max' => '500',
                'step' => '1',
            ),
            'active_callback' => array(
                array(
                    'setting' => 'search_header_back_title',
                    'operator' => '!=',
                    'value' => '',
                ),
                array(
                    'setting' => 'search_header_show',
                    'operator' => '==',
                    'value' => true,
                ),

            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'select',
            'settings' => 'search_header_back_title_align',
            'label' => esc_html__('Back Title Align', 'musart'),
            'section' => 'search_header',
            'default' => 'center',
            'priority' => 10,
            'choices' => array(
                'center' => esc_attr__('Center', 'musart'),
                'left' => esc_attr__('Left', 'musart'),
                'right' => esc_attr__('Right', 'musart'),
            ),
            'active_callback' => array(
                array(
                    'setting' => 'search_header_back_title',
                    'operator' => '!=',
                    'value' => '',
                ),
                array(
                    'setting' => 'search_header_show',
                    'operator' => '==',
                    'value' => true,
                ),

            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'text',
            'settings' => 'search_header_sub_title',
            'label' => esc_html__('Sub Title', 'musart'),
            'section' => 'search_header',
            'default' => '',
            'priority' => 10,
            'active_callback' => array(
                array(
                    'setting' => 'search_header_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'number',
            'settings' => 'search_header_sub_title_padding_bottom',
            'label' => esc_attr__('Sub Title Padding Bottom', 'musart'),
            'section' => 'search_header',
            'default' => 40,
            'priority' => 10,
            'choices' => array(
                'min' => '0',
                'max' => '500',
                'step' => '1',
            ),
            'active_callback' => array(
                array(
                    'setting' => 'search_header_sub_title',
                    'operator' => '!=',
                    'value' => '',
                ),
                array(
                    'setting' => 'search_header_show',
                    'operator' => '==',
                    'value' => true,
                ),

            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'select',
            'settings' => 'search_header_sub_title_align',
            'label' => esc_html__('Sub Title Align', 'musart'),
            'section' => 'search_header',
            'default' => 'center',
            'priority' => 10,
            'choices' => array(
                'center' => esc_attr__('Center', 'musart'),
                'left' => esc_attr__('Left', 'musart'),
                'right' => esc_attr__('Right', 'musart'),
            ),
            'active_callback' => array(
                array(
                    'setting' => 'search_header_sub_title',
                    'operator' => '!=',
                    'value' => '',
                ),
                array(
                    'setting' => 'search_header_show',
                    'operator' => '==',
                    'value' => true,
                ),

            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'editor',
            'settings' => 'search_header_content',
            'label' => esc_html__('Content', 'musart'),
            'section' => 'search_header',
            'default' => '',
            'priority' => 10,
            'active_callback' => array(
                array(
                    'setting' => 'search_header_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'text',
            'settings' => 'search_header_video_link',
            'label' => esc_html__('Video Link', 'musart'),
            'section' => 'search_header',
            'description' => esc_html__('Supported YouTube and Vimeo video link', 'musart'),
            'default' => '',
            'priority' => 10,
            'active_callback' => array(
                array(
                    'setting' => 'search_header_show',
                    'operator' => '==',
                    'value' => true,
                ),
            ),
        ));
        Musart_Options::add_field( array(
            'type' => 'select',
            'settings' => 'search_header_video_style',
            'label' => esc_html__('Icon Video Style', 'musart'),
            'section' => 'search_header',
            'default' => false,
            'priority' => 10,
            'choices' => array(
                false => esc_attr__('Black', 'musart'),
                '2' => esc_attr__('Black 2', 'musart'),
                'light' => esc_attr__('Light', 'musart'),
                '2-light' => esc_attr__('Light 2', 'musart')
            ),
            'active_callback' => array(
                array(
                    'setting' => 'search_header_show',
                    'operator' => '==',
                    'value' => true,
                ),
                array(
                    'setting' => 'search_header_video_link',
                    'operator' => '!=',
                    'value' => '',
                ),
            ),
        ));
    }

    add_action('init', 'musart_initial_kirki_options');
}
if(!function_exists('kirki_initial_custom_post')):
    function kirki_initial_custom_post($type_posts){
        if(is_array($type_posts) && isset($type_posts) && !empty($type_posts)){
            $sidebars = musart_get_sidebars();
            foreach($type_posts as $type_post){
                //main panel
                Musart_Options::add_panel($type_post, array(
                    'priority' => 9,
                    'title' => ucfirst($type_post),
                ));
                //main sections inner panel
                Musart_Options::add_section($type_post.'_content', array(
                    'title' => esc_html__('Content', 'musart'),
                    'priority' => 12,
                    'panel' => $type_post,
                ));
                Musart_Options::add_section($type_post.'_header', array(
                    'title' => esc_html__('Header', 'musart'),
                    'priority' => 12,
                    'panel' => $type_post,
                ));
                Musart_Options::add_section($type_post.'_sidebar', array(
                    'title' => esc_html__('Sidebar', 'musart'),
                    'priority' => 12,
                    'panel' => $type_post,
                ));
                Musart_Options::add_section($type_post.'_archive', array(
                    'title' => esc_html__('Archive', 'musart'),
                    'priority' => 12,
                    'panel' => $type_post,
                ));
                Musart_Options::add_section($type_post.'_single', array(
                    'title' => esc_html__('Single', 'musart'),
                    'priority' => 12,
                    'panel' => $type_post,
                ));
                Musart_Options::add_section($type_post.'_meta', array(
                    'title' => esc_html__('Meta', 'musart'),
                    'priority' => 12,
                    'panel' => $type_post,
                ));
                /**
                 * $type_post. Header
                 */
                Musart_Options::add_field( array(
                    'type' => 'toggle',
                    'settings' => $type_post.'_header_show',
                    'label' => esc_html__('Show', 'musart'),
                    'section' => $type_post.'_header',
                    'default' => 'on',
                    'priority' => 10
                ));
                Musart_Options::add_field( array(
                    'type' => 'toggle',
                    'settings' => $type_post.'_header_show_title',
                    'label' => esc_html__('Show Title', 'musart'),
                    'section' => $type_post.'_header',
                    'default' => 'on',
                    'priority' => 10,
                    'active_callback' => array(
                        array(
                            'setting' => $type_post.'_header_show',
                            'operator' => '==',
                            'value' => true,
                        ),
                    ),
                ));
                Musart_Options::add_field( array(
                    'type' => 'text',
                    'settings' => $type_post.'_header_archive_custom_title',
                    'label' => esc_html__('Custom Archive Title', 'musart'),
                    'section' => $type_post.'_header',
                    'default' => '',
                    'priority' => 10,
                    'active_callback' => array(
                        array(
                            'setting' => $type_post.'_header_show_title',
                            'operator' => '==',
                            'value' => true,
                        ),
                        array(
                            'setting' => $type_post.'_header_show',
                            'operator' => '==',
                            'value' => true,
                        ),
                    ),
                ));
                Musart_Options::add_field( array(
                    'type' => 'number',
                    'settings' => $type_post.'_header_title_padding_bottom',
                    'label' => esc_attr__('Title Padding Bottom', 'musart'),
                    'section' => $type_post.'_header',
                    'default' => 0,
                    'priority' => 10,
                    'choices' => array(
                        'min' => '0',
                        'max' => '500',
                        'step' => '1',
                    ),
                    'active_callback' => array(
                        array(
                            'setting' => $type_post.'_header_show_title',
                            'operator' => '==',
                            'value' => true,
                        ),
                        array(
                            'setting' => $type_post.'_header_show',
                            'operator' => '==',
                            'value' => true,
                        ),
                    ),
                ));
                Musart_Options::add_field( array(
                    'type' => 'select',
                    'settings' => $type_post.'_header_title_looks_like',
                    'label' => esc_html__('Title Looks Like', 'musart'),
                    'section' => $type_post.'_header',
                    'default' => '',
                    'priority' => 10,
                    'choices' => array(
                        '' => esc_attr__('disabled', 'musart'),
                        'h1' => esc_attr__('h1', 'musart'),
                        'h2' => esc_attr__('h2', 'musart'),
                        'h3' => esc_attr__('h3', 'musart'),
                        'h4' => esc_attr__('h4', 'musart'),
                        'h5' => esc_attr__('h5', 'musart'),
                        'h6' => esc_attr__('h6', 'musart'),
                        'display-1' => esc_attr__('display-1', 'musart'),
                        'display-2' => esc_attr__('display-2', 'musart'),
                        'display-3' => esc_attr__('display-3', 'musart'),
                        'display-4' => esc_attr__('display-4', 'musart')
                    ),
                    'active_callback' => array(
                        array(
                            'setting' => $type_post.'_header_show_title',
                            'operator' => '==',
                            'value' => true,
                        ),
                        array(
                            'setting' => $type_post.'_header_show',
                            'operator' => '==',
                            'value' => true,
                        ),
                    ),
                ));
                Musart_Options::add_field( array(
                    'type' => 'select',
                    'settings' => $type_post.'_header_title_align',
                    'label' => esc_html__('Title Align', 'musart'),
                    'section' => $type_post.'_header',
                    'default' => 'center',
                    'priority' => 10,
                    'choices' => array(
                        'center' => esc_attr__('Center', 'musart'),
                        'left' => esc_attr__('Left', 'musart'),
                        'right' => esc_attr__('Right', 'musart'),
                    ),
                    'active_callback' => array(
                        array(
                            'setting' => $type_post.'_header_show_title',
                            'operator' => '==',
                            'value' => true,
                        ),
                        array(
                            'setting' => $type_post.'_header_show',
                            'operator' => '==',
                            'value' => true,
                        ),
                    ),
                ));
                Musart_Options::add_field( array(
                    'type' => 'select',
                    'settings' => $type_post.'_header_size',
                    'label' => esc_html__('Size', 'musart'),
                    'section' => $type_post.'_header',
                    'default' => false,
                    'priority' => 10,
                    'choices' => array(
                        false => esc_attr__('Default', 'musart'),
                        'sm' => esc_attr__('Small', 'musart'),
                        'md' => esc_attr__('Middle', 'musart'),
                        'lg' => esc_attr__('Large', 'musart'),
                        'xl' => esc_attr__('X-Large', 'musart'),
                        'full' => esc_attr__('Full', 'musart'),
                    ),
                    'active_callback' => array(
                        array(
                            'setting' => $type_post.'_header_show',
                            'operator' => '==',
                            'value' => true,
                        ),
                    ),
                ));
                Musart_Options::add_field( array(
                    'type' => 'toggle',
                    'settings' => $type_post.'_header_parallax',
                    'label' => esc_html__('Parallax for Background Image', 'musart'),
                    'section' => $type_post.'_header',
                    'default' => 'on',
                    'priority' => 10,
                    'active_callback' => array(
                        array(
                            'setting' => $type_post.'_header_show',
                            'operator' => '==',
                            'value' => true,
                        ),
                    ),
                ));
                Musart_Options::add_field( array(
                    'type' => 'toggle',
                    'settings' => $type_post.'_header_parallax_opacity',
                    'label' => esc_html__('Opacity Parallax Content', 'musart'),
                    'section' => $type_post.'_header',
                    'default' => 'on',
                    'priority' => 10,
                    'active_callback' => array(
                        array(
                            'setting' => $type_post.'_header_show',
                            'operator' => '==',
                            'value' => true,
                        ),
                    ),
                ));
                Musart_Options::add_field( array(
                    'type' => 'select',
                    'settings' => $type_post.'_header_type_image',
                    'label' => esc_html__('Select Type of Background Image', 'musart'),
                    'section' => $type_post.'_header',
                    'default' => 'featured',
                    'priority' => 10,
                    'choices' => array(
                        false => esc_attr__('False', 'musart'),
                        'featured' => esc_attr__('Featured', 'musart'),
                        'custom' => esc_attr__('Custom', 'musart'),
                    ),
                    'active_callback' => array(
                        array(
                            'setting' => $type_post.'_header_show',
                            'operator' => '==',
                            'value' => true,
                        ),
                    ),
                ));
                Musart_Options::add_field( array(
                    'type' => 'image',
                    'settings' => $type_post.'_header_background_image',
                    'label' => esc_html__('Background Image', 'musart'),
                    'section' => $type_post.'_header',
                    'default' => get_template_directory_uri() . '/assets/images/default-banner.jpg',
                    'priority' => 10,
                    'active_callback' => array(
                        array(
                            'setting' => $type_post.'_header_show',
                            'operator' => '==',
                            'value' => true,
                        ),
                        array(
                            'setting' => $type_post.'_header_type_image',
                            'operator' => '==',
                            'value' => 'custom',
                        ),
                    ),
                ));
                Musart_Options::add_field( array(
                    'type' => 'image',
                    'settings' => $type_post.'_header_archive_background_image',
                    'label' => esc_html__('Background Archive Image', 'musart'),
                    'section' => $type_post.'_header',
                    'default' => get_template_directory_uri() . '/assets/images/default-banner.jpg',
                    'priority' => 10,
                    'active_callback' => array(
                        array(
                            'setting' => $type_post.'_header_show',
                            'operator' => '==',
                            'value' => true,
                        ),
                    ),
                ));
                Musart_Options::add_field( array(
                    'type' => 'slider',
                    'settings' => $type_post.'_header_background_image_opacity',
                    'label' => esc_attr__('Opacity', 'musart'),
                    'section' => $type_post.'_header',
                    'default' => 5,
                    'priority' => 10,
                    'choices' => array(
                        'min' => '0',
                        'max' => '10',
                        'step' => '1',
                    ),
                    'active_callback' => array(
                        array(
                            'setting' => $type_post.'_header_type_image',
                            'operator' => '!=',
                            'value' => false,
                        ),
                        array(
                            'setting' => $type_post.'_header_show',
                            'operator' => '==',
                            'value' => true,
                        ),

                    ),
                ));
                Musart_Options::add_field( array(
                    'type' => 'text',
                    'settings' => $type_post.'_header_back_title',
                    'label' => esc_html__('Back Title', 'musart'),
                    'section' => $type_post.'_header',
                    'default' => '',
                    'priority' => 10,
                    'active_callback' => array(
                        array(
                            'setting' => $type_post.'_header_show',
                            'operator' => '==',
                            'value' => true,
                        ),
                    ),
                ));
                Musart_Options::add_field( array(
                    'type' => 'slider',
                    'settings' => $type_post.'_header_back_title_opacity',
                    'label' => esc_attr__('Back Title Opacity', 'musart'),
                    'section' => $type_post.'_header',
                    'default' => 1,
                    'priority' => 10,
                    'choices' => array(
                        'min' => '0',
                        'max' => '10',
                        'step' => '1',
                    ),
                    'active_callback' => array(
                        array(
                            'setting' => $type_post.'_header_show',
                            'operator' => '==',
                            'value' => true,
                        ),
                        array(
                            'setting' => $type_post.'_header_back_title',
                            'operator' => '!=',
                            'value' => '',
                        ),
                    ),
                ));
                Musart_Options::add_field( array(
                    'type' => 'number',
                    'settings' => $type_post.'_header_back_title_padding_bottom',
                    'label' => esc_attr__('Back Title Padding Bottom', 'musart'),
                    'section' => $type_post.'_header',
                    'default' => 0,
                    'priority' => 10,
                    'choices' => array(
                        'min' => '0',
                        'max' => '500',
                        'step' => '1',
                    ),
                    'active_callback' => array(
                        array(
                            'setting' => $type_post.'_header_show',
                            'operator' => '==',
                            'value' => true,
                        ),
                        array(
                            'setting' => $type_post.'_header_back_title',
                            'operator' => '!=',
                            'value' => '',
                        ),
                    ),
                ));
                Musart_Options::add_field( array(
                    'type' => 'select',
                    'settings' => $type_post.'_header_back_title_align',
                    'label' => esc_html__('Back Title Align', 'musart'),
                    'section' => $type_post.'_header',
                    'default' => 'center',
                    'priority' => 10,
                    'choices' => array(
                        'center' => esc_attr__('Center', 'musart'),
                        'left' => esc_attr__('Left', 'musart'),
                        'right' => esc_attr__('Right', 'musart'),
                    ),
                    'active_callback' => array(
                        array(
                            'setting' => $type_post.'_header_back_title',
                            'operator' => '!=',
                            'value' => '',
                        ),
                        array(
                            'setting' => $type_post.'_header_show',
                            'operator' => '==',
                            'value' => true,
                        ),

                    ),
                ));
                Musart_Options::add_field( array(
                    'type' => 'text',
                    'settings' => $type_post.'_header_sub_title',
                    'label' => esc_html__('Sub Title', 'musart'),
                    'section' => $type_post.'_header',
                    'default' => '',
                    'priority' => 10,
                    'active_callback' => array(
                        array(
                            'setting' => $type_post.'_header_show',
                            'operator' => '==',
                            'value' => true,
                        ),
                    ),
                ));
                Musart_Options::add_field( array(
                    'type' => 'number',
                    'settings' => $type_post.'_header_sub_title_padding_bottom',
                    'label' => esc_attr__('Sub Title Padding Bottom', 'musart'),
                    'section' => $type_post.'_header',
                    'default' => 40,
                    'priority' => 10,
                    'choices' => array(
                        'min' => '0',
                        'max' => '500',
                        'step' => '1',
                    ),
                    'active_callback' => array(
                        array(
                            'setting' => $type_post.'_header_show',
                            'operator' => '==',
                            'value' => true,
                        ),
                        array(
                            'setting' => $type_post.'_header_sub_title',
                            'operator' => '!=',
                            'value' => '',
                        ),
                    ),
                ));
                Musart_Options::add_field( array(
                    'type' => 'select',
                    'settings' => $type_post.'_header_sub_title_align',
                    'label' => esc_html__('Sub Title Align', 'musart'),
                    'section' => $type_post.'_header',
                    'default' => 'center',
                    'priority' => 10,
                    'choices' => array(
                        'center' => esc_attr__('Center', 'musart'),
                        'left' => esc_attr__('Left', 'musart'),
                        'right' => esc_attr__('Right', 'musart'),
                    ),
                    'active_callback' => array(
                        array(
                            'setting' => $type_post.'_header_sub_title',
                            'operator' => '!=',
                            'value' => '',
                        ),
                        array(
                            'setting' => $type_post.'_header_show',
                            'operator' => '==',
                            'value' => true,
                        ),

                    ),
                ));
                Musart_Options::add_field( array(
                    'type' => 'editor',
                    'settings' => $type_post.'_header_content',
                    'label' => esc_html__('Content', 'musart'),
                    'section' => $type_post.'_header',
                    'default' => '',
                    'priority' => 10,
                    'active_callback' => array(
                        array(
                            'setting' => $type_post.'_header_show',
                            'operator' => '==',
                            'value' => true,
                        ),
                    ),
                ));
                Musart_Options::add_field( array(
                    'type' => 'text',
                    'settings' => $type_post.'_header_video_link',
                    'label' => esc_html__('Video Link', 'musart'),
                    'section' => $type_post.'_header',
                    'default' => '',
                    'description' => esc_html__('Supported YouTube and Vimeo video link', 'musart'),
                    'priority' => 10,
                    'active_callback' => array(
                        array(
                            'setting' => $type_post.'_header_show',
                            'operator' => '==',
                            'value' => true,
                        ),
                    ),
                ));
                Musart_Options::add_field( array(
                    'type' => 'select',
                    'settings' => $type_post.'_header_video_style',
                    'label' => esc_html__('Icon Video Style', 'musart'),
                    'section' => $type_post.'_header',
                    'default' => false,
                    'priority' => 10,
                    'choices' => array(
                        false => esc_attr__('Black', 'musart'),
                        '2' => esc_attr__('Black 2', 'musart'),
                        'light' => esc_attr__('Light', 'musart'),
                        '2-light' => esc_attr__('Light 2', 'musart')
                    ),
                    'active_callback' => array(
                        array(
                            'setting' => $type_post.'_header_show',
                            'operator' => '==',
                            'value' => true,
                        ),
                        array(
                            'setting' => $type_post.'_header_video_link',
                            'operator' => '!=',
                            'value' => '',
                        ),
                    ),
                ));

                /**
                 * $type_post. Sidebar
                 * */
                $default_sidebar_color = '#f7f7f7';
                if($type_post == 'playlist'){
                    $default_sidebar_color = '#262626';
                }
                Musart_Options::add_field( array(
                    'type' => 'toggle',
                    'settings' => 'sidebar_'.$type_post.'_show',
                    'label' => esc_html__('Show', 'musart'),
                    'section' => $type_post.'_sidebar',
                    'default' => 'off',
                    'priority' => 10,
                ));
                Musart_Options::add_field( array(
                    'type' => 'select',
                    'settings' => 'sidebar_'.$type_post.'_list',
                    'label' => esc_html__('Type', 'musart'),
                    'section' => $type_post.'_sidebar',
                    'default' => 'single_page',
                    'priority' => 10,
                    'choices' => $sidebars,
                    'active_callback' => array(
                        array(
                            'setting' => 'sidebar_'.$type_post.'_show',
                            'operator' => '==',
                            'value' => true,
                        ),
                    ),
                ));
                Musart_Options::add_field( array(
                    'type' => 'select',
                    'settings' => 'sidebar_'.$type_post.'_side',
                    'label' => esc_html__('Side', 'musart'),
                    'section' => $type_post.'_sidebar',
                    'default' => 'right',
                    'priority' => 10,
                    'choices' => array(
                        'right' => esc_attr__('Right', 'musart'),
                        'left' => esc_attr__('Left', 'musart'),
                        'both' => esc_attr__('Both', 'musart'),
                    ),
                    'active_callback' => array(
                        array(
                            'setting' => 'sidebar_'.$type_post.'_show',
                            'operator' => '==',
                            'value' => true,
                        ),
                    ),
                ));
                Musart_Options::add_field( array(
                    'type' => 'select',
                    'settings' => 'sidebar_'.$type_post.'_additional_list',
                    'label' => esc_html__('Type additional', 'musart'),
                    'section' => $type_post.'_sidebar',
                    'priority' => 10,
                    'choices' => $sidebars,
                    'active_callback' => array(
                        array(
                            'setting' => 'sidebar_'.$type_post.'_show',
                            'operator' => '==',
                            'value' => true,
                        ),
                        array(
                            'setting' => 'sidebar_'.$type_post.'_side',
                            'operator' => '==',
                            'value' => 'both',
                        ),
                    ),
                ));
                Musart_Options::add_field( array(
                    'type' => 'toggle',
                    'settings' => 'sidebar_'.$type_post.'_sticky',
                    'label' => esc_html__('Sticky', 'musart'),
                    'section' => $type_post.'_sidebar',
                    'default' => 'on',
                    'priority' => 10,
                    'active_callback' => array(
                        array(
                            'setting' => 'sidebar_'.$type_post.'_show',
                            'operator' => '==',
                            'value' => true,
                        ),
                    ),
                ));
                Musart_Options::add_field( array(
                    'type' => 'color',
                    'settings' => 'sidebar_'.$type_post . '_background_color',
                    'label' => esc_attr__('Background Color', 'musart'),
                    'section' => $type_post . '_sidebar',
                    'default' => $default_sidebar_color,
                    'priority' => 10,
                    'choices'     => array(
                        'alpha' => true,
                    ),
                    'output' => array(
                        array(
                            'element' => '.nk-sidebar.nk-sidebar-'.$type_post.':after',
                            'property' => 'background-color',
                        ),
                    ),
                    'active_callback' => array(
                        array(
                            'setting' => 'sidebar_'.$type_post.'_show',
                            'operator' => '==',
                            'value' => true,
                        ),
                    ),
                ));
                Musart_Options::add_field( array(
                    'type' => 'color',
                    'settings' => 'sidebar_'.$type_post . '_text_color',
                    'label' => esc_attr__('Text Color', 'musart'),
                    'section' => $type_post . '_sidebar',
                    'default' => 'inherit',
                    'priority' => 10,
                    'choices'     => array(
                        'alpha' => true,
                    ),
                    'output' => array(
                        array(
                            'element' => '.nk-sidebar.nk-sidebar-'.$type_post,
                            'property' => 'color',
                        ),
                    ),
                    'active_callback' => array(
                        array(
                            'setting' => 'sidebar_'.$type_post.'_show',
                            'operator' => '==',
                            'value' => true,
                        ),
                    ),
                ));

                /**
                 * $type_post. Content
                 * */
                Musart_Options::add_field( array(
                    'type' => 'toggle',
                    'settings' => $type_post.'_inner_boxed',
                    'label' => esc_html__('Boxed Content', 'musart'),
                    'section' => $type_post.'_content',
                    'default' => 'on',
                    'priority' => 10,
                ));
                Musart_Options::add_field( array(
                    'type' => 'toggle',
                    'settings' => $type_post.'_show_title',
                    'label' => esc_html__('Show Title', 'musart'),
                    'section' => $type_post.'_content',
                    'default' => 'off',
                    'priority' => 10,
                ));

                /**
                 * $type_post. Archive
                 */
                if($type_post == 'playlist'){
                    Musart_Options::add_field( array(
                        'type' => 'image',
                        'settings' => $type_post.'_no_image',
                        'label' => esc_html__('No Image', 'musart'),
                        'section' => $type_post.'_archive',
                        'default' => get_template_directory_uri() . '/assets/images/no-image.jpg',
                        'priority' => 10,
                    ));
                    Musart_Options::add_field( array(
                        'type' => 'toggle',
                        'settings' => $type_post . '_rotate',
                        'label' => esc_html__('Inverse', 'musart'),
                        'section' => $type_post . '_single',
                        'default' => 'off',
                        'priority' => 10,
                    ));
                    Musart_Options::add_field( array(
                        'type' => 'color',
                        'settings' => $type_post . '_background_archive_color',
                        'label' => esc_attr__('Background Color', 'musart'),
                        'section' => $type_post . '_archive',
                        'default' => '#1c1c1c',
                        'priority' => 10,
                        'choices'     => array(
                            'alpha' => true,
                        ),
                        'output' => array(
                            array(
                                'element' => '.bg-custom-playlist-archive-color',
                                'property' => 'background-color',
                            ),
                        ),
                    ));
                    Musart_Options::add_field( array(
                        'type' => 'color',
                        'settings' => $type_post . '_archive_text_color',
                        'label' => esc_attr__('Text Color', 'musart'),
                        'section' => $type_post . '_archive',
                        'default' => '#fff',
                        'priority' => 10,
                        'choices'     => array(
                            'alpha' => true,
                        ),
                        'output' => array(
                            array(
                                'element' => '.text-custom-playlist-archive-color',
                                'property' => 'color',
                            ),
                        ),
                    ));

                }
                Musart_Options::add_field( array(
                    'type' => 'select',
                    'settings' => $type_post.'_pagination',
                    'label' => esc_html__('Pagination', 'musart'),
                    'section' => $type_post.'_archive',
                    'default' => 'load_more',
                    'priority' => 10,
                    'choices' => array(
                        false => esc_html__("No Pagination", 'musart'),
                        true => esc_html__("Simple Pagination", 'musart'),
                        'load_more' => esc_html__("Load More button", 'musart'),
                        'infinite' => esc_html__("Infinite Scroll", 'musart'),
                    ),
                ));
                if ( $type_post == 'event' ) {
                    Musart_Options::add_field( array(
                        'type' => 'toggle',
                        'settings' => $type_post.'_show_upcoming_events',
                        'label' => esc_html__('Show Only Upcoming Events', 'musart'),
                        'section' => $type_post.'_archive',
                        'default' => 'off',
                        'priority' => 10,
                    ));
                }
                /**
                 * $type_post. Single
                 */
                if($type_post == 'event') {
                    Musart_Options::add_field( array(
                        'type' => 'toggle',
                        'settings' => $type_post . '_show_meta',
                        'label' => esc_html__('Show Meta', 'musart'),
                        'section' => $type_post . '_meta',
                        'default' => 'on',
                        'priority' => 10,
                    ));
                    Musart_Options::add_field( array(
                        'type' => 'select',
                        'settings' => $type_post.'_position_meta',
                        'label' => esc_html__('Position', 'musart'),
                        'section' => $type_post.'_meta',
                        'priority' => 10,
                        'choices' => array(
                            'header' => esc_html__("Header", 'musart'),
                            'out header' => esc_html__("Under Header", 'musart'),
                            'before content' => esc_html__("Before Content", 'musart'),
                            'after content' => esc_html__("After Content", 'musart'),
                        ),
                        'active_callback' => array(
                            array(
                                'setting' => $type_post . '_show_meta',
                                'operator' => '==',
                                'value' => true,
                            ),
                        ),
                    ));
                }
                if($type_post == 'playlist') {
                    Musart_Options::add_field( array(
                        'type' => 'toggle',
                        'settings' => $type_post . '_rotate',
                        'label' => esc_html__('Inverse', 'musart'),
                        'section' => $type_post . '_single',
                        'default' => 'off',
                        'priority' => 10,
                    ));
                    Musart_Options::add_field( array(
                        'type' => 'color',
                        'settings' => $type_post . '_background_color',
                        'label' => esc_attr__('Background Color', 'musart'),
                        'section' => $type_post . '_single',
                        'default' => '#1c1c1c',
                        'priority' => 10,
                        'choices'     => array(
                            'alpha' => true,
                        ),
                        'output' => array(
                            array(
                                'element' => '.bg-custom-playlist-color',
                                'property' => 'background-color',
                            ),
                        ),
                    ));
                    Musart_Options::add_field( array(
                        'type' => 'color',
                        'settings' => $type_post . '_text_color',
                        'label' => esc_attr__('Text Color', 'musart'),
                        'section' => $type_post . '_single',
                        'default' => '#fff',
                        'priority' => 10,
                        'choices'     => array(
                            'alpha' => true,
                        ),
                        'output' => array(
                            array(
                                'element' => '.text-custom-playlist-color',
                                'property' => 'color',
                            ),
                        ),
                    ));
                }
                Musart_Options::add_field( array(
                    'type' => 'toggle',
                    'settings' => $type_post . '_detail_show_title',
                    'label' => esc_html__('Show Title', 'musart'),
                    'section' => $type_post . '_single',
                    'default' => 'off',
                    'priority' => 10,
                ));
            }
        }
    }
endif;
if (!function_exists('musart_get_theme_mod')):
    function musart_get_theme_mod($name = null, $use_acf = null, $postId = null, $acf_name = null)
    {

        if ($name == null) {
            return null;
        }
        $value = null;

        // try get value from meta box
        if ($use_acf) {
            $value = musart_get_metabox($acf_name ? $acf_name : $name, $postId);
        }

        // get value from options
        if (($value === null || $value === 'default')) {
            if (class_exists('Musart_Options')) {
                $value = Musart_Options::get_option($name);
            }
        }

        $value = apply_filters('musart_filter_get_theme_mod', $value, $name);
        return $value;
    }
endif;

// get metabox
if (!function_exists('musart_get_metabox')):
    function musart_get_metabox($name = null, $postId = null)
    {
        $value = null;

        // try get value from meta box
        if (function_exists('get_field')) {
            if ($postId == null) {
                $postId = get_the_ID();
            }
            $value = get_field($name, $postId);
        }

        return $value;
    }
endif;
