<?php
/**
 * Custom template tags for this theme.
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package musart
 */

if (!function_exists('musart_posts_navigation')) :
    /**
     * Display navigation to next/previous set of posts when applicable.
     *
     * @todo Remove this function when WordPress 4.3 is released.
     */
    function musart_posts_navigation($query = null)
    {
        if ($query == null) {
            $queryName = isset($GLOBALS['yp_query']) ? 'yp_query' : 'wp_query';

            // Don't print empty markup if there's only one page.
            if ($GLOBALS[$queryName]->max_num_pages < 1) {
                return;
            }

            $query = $GLOBALS[$queryName];
        }
        $page_links = paginate_links(apply_filters('nk_pagination_args', array(
            'base' => esc_url_raw(str_replace(999999999, '%#%', remove_query_arg('add-to-cart', get_pagenum_link(999999999, false)))),
            'format' => '',
            'add_args' => '',
            'current' => max(1, get_query_var('page'), get_query_var('paged')),
            'total' => $query->max_num_pages,
            'prev_text' => '<span class="nk-icon-arrow-left"></span>',
            'next_text' => '<span class="nk-icon-arrow-right"></span>',
            'type' => 'array',
            'end_size' => 3,
            'mid_size' => 3
        )));
        if (!is_array($page_links)) {
            return;
        } else {
            $page_prev_or_next_links = $page_links;
            $prev_link = array_shift($page_prev_or_next_links);
            $next_link = array_pop($page_prev_or_next_links);
        }

        ?>
        <div class="nk-pagination nk-pagination-center">

            <nav>
                <?php foreach ($page_links as $cur) : ?>
                    <?php
                    if ((strpos($cur, 'prev page-numbers') === false) && (strpos($cur, 'next page-numbers') === false)):
                        if (strpos($cur, 'current') !== false):
                            $cur = str_replace('page-numbers current', musart_sanitize_class('nk-pagination-current'), $cur);
                        else:
                            if (strpos($cur, 'dots') !== false):
                                $cur = str_replace('class="page-numbers dots"', '', $cur);
                            else:
                                $cur = str_replace('class="page-numbers"', '', $cur);
                            endif;
                        endif;
                        echo wp_kses_post($cur);
                    endif; ?>
                <?php endforeach; ?>
            </nav>

        </div>
        <?php
    }
endif;

if (!function_exists('musart_posted_on')) :
    /**
     * Prints HTML with meta information for the current post-date/time and author.
     */
    function musart_posted_on($get = false, $showDate = true, $showByline = true)
    {
        $time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
        if (get_the_time('U') !== get_the_modified_time('U')) {
            $time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time>';
        }

        $time_string = sprintf($time_string,
            esc_attr(get_the_date('c')),
            esc_html(get_the_date())
        );

        $posted_on = '<span class="posted-on">' . sprintf(esc_html_x('%s %s', 'post date', 'musart'), '<i class="fas fa-calendar"></i>', $time_string) . '</span>';

        $byline = '<span class="byline"> ' .
            sprintf(esc_html_x('by %s', 'post author', 'musart'), '<span class="author vcard"><a class="url fn n" href="' . esc_url(get_author_posts_url(get_the_author_meta('ID'))) . '">' . esc_html(get_the_author()) . '</a></span>') .
            '</span>';

        if ($get) {
            return ($showDate ? wp_kses( $posted_on, musart_allowed_html() ) : '') . ($showByline ? wp_kses( $byline, musart_allowed_html() ) : '');
        } else {
            echo ($showDate ? wp_kses( $posted_on, musart_allowed_html() ) : '') . ($showByline ? wp_kses( $byline, musart_allowed_html() ) : '');
        }
    }
endif;
if (!function_exists('musart_post_tags')) :
    /**
     * Prints HTML with post tags
     */
    function musart_post_tags()
    {
        $posttags = get_the_tags();
        $tags_string = '';
        if ($posttags) {

            foreach ($posttags as $tag) {
                $tags_string .= '<a href="' . get_tag_link($tag->term_id) . '">' . $tag->name . '</a> ';

            }
        }
            $tags_string = sprintf(
                esc_html__('%s', 'musart'),
                $tags_string
            ); // WPCS: XSS OK

            echo ' <div class="nk-post-meta">
                        <div class="nk-post-tags">&nbsp;' . $tags_string . '</div>
                   </div>';

    }
endif;
if (!function_exists('musart_read_more')) :
    /**
     * Prints HTML with post tags
     */
    function musart_read_more()
    {
        printf(
            '<a href="%s" class="btn read-more pull-left">%s</a>',
            esc_url(get_permalink()),
            esc_html__('Read More', 'musart')
        ); // WPCS: XSS OK
    }
endif;

if (!function_exists('musart_entry_footer')) :
    /**
     * Prints HTML with meta information for the categories, tags and comments.
     */
    function musart_entry_footer()
    {
        edit_post_link(esc_html__('Edit', 'musart'), '<div class="edit-link pull-right">', '</div><div class="clearfix"></div>');
    }
endif;

/**
 * Returns true if a blog has more than 1 category.
 *
 * @return bool
 */
if (!function_exists('musart_categorized_blog')) :
    function musart_categorized_blog()
    {
        if (false === ($all_the_cool_cats = get_transient('musart_categories'))) {
            // Create an array of all the categories that are attached to posts.
            $all_the_cool_cats = get_categories(array(
                'fields' => 'ids',
                'hide_empty' => 1,
                // We only need to know if there is more than one category.
                'number' => 2,
            ));

            // Count the number of categories that are attached to the posts.
            $all_the_cool_cats = count($all_the_cool_cats);

            set_transient('musart_categories', $all_the_cool_cats);
        }

        if ($all_the_cool_cats > 1) {
            // This blog has more than 1 category so musart_categorized_blog should return true.
            return true;
        } else {
            // This blog has only 1 category so musart_categorized_blog should return false.
            return false;
        }
    }
endif;
/**
 * Flush out the transients used in musart_categorized_blog.
 */
if (!function_exists('musart_category_transient_flusher')) :
    function musart_category_transient_flusher()
    {
        if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) {
            return;
        }
        // Like, beat it. Dig?
        delete_transient('musart_categories');
    }
endif;

add_action('edit_category', 'musart_category_transient_flusher');
add_action('save_post', 'musart_category_transient_flusher');

if (!function_exists('musart_comment_text')) :
    function musart_comment_text($text = null)
    {
        if ($text == null) {
            $text = get_comment_text();
        }
        return wp_kses_post($text);
    }
endif;

if (!function_exists('musart_show_media_extra_attachment_fields')) :
    function musart_show_media_extra_attachment_fields($form_fields, $post)
    {
        $form_fields['link'] = array(
            'label' => 'Link',
            'input' => 'text',
            'value' => get_post_meta($post->ID, 'link', true),
            'helps' => 'This property is used only in the posts or in nk_images_carousel shortcode',
        );
        return $form_fields;
    }
endif;

if (!function_exists('musart_save_media_extra_attachment_fields')) :
    function musart_save_media_extra_attachment_fields($post, $attachment)
    {
        if (isset($attachment['link']))
            update_post_meta($post['ID'], 'link', $attachment['link']);
        return $post;
    }
endif;
add_filter('attachment_fields_to_edit', 'musart_show_media_extra_attachment_fields', 10, 2);
add_filter('attachment_fields_to_save', 'musart_save_media_extra_attachment_fields', 10, 2);

/**
 * Display navigation to next/previous set of posts comments when applicable.
 */
if (!function_exists('musart_posts_comments_navigation')) :
    function musart_posts_comments_navigation()
    {
        $paginate_comments_links = paginate_comments_links(array(
            'echo' => false,
            'prev_text' => '<span class="nk-icon-arrow-left"></span>',
            'next_text' => '<span class="nk-icon-arrow-right"></span>',
            'type' => 'array',
            'end_size' => 3,
            'mid_size' => 3));
        if (!is_array($paginate_comments_links)) {
            return;
        } else {
            $page_prev_or_next_links = $paginate_comments_links;
            $prev_link = array_shift($page_prev_or_next_links);
            $next_link = array_pop($page_prev_or_next_links);
        }
        ?>
        <div class="nk-pagination nk-pagination-left">
            <?php if (isset($prev_link)): ?>
                <?php if (strpos($prev_link, 'prev page-numbers') !== false): ?>
                    <?php echo(str_replace('prev page-numbers', musart_sanitize_class('nk-pagination-prev'), $prev_link)); ?>
                <?php else: ?>
                    <a href="#"
                       class="nk-pagination-prev <?php echo musart_sanitize_class(strpos($prev_link, 'current') !== false ? 'disabled' : ''); ?>">
                        <span class="nk-icon-arrow-left"></span>
                    </a>
                <?php endif; ?>
            <?php endif; ?>
            <nav>
                <?php foreach ($paginate_comments_links as $cur) : ?>
                    <?php
                    if ((strpos($cur, 'prev page-numbers') === false) && (strpos($cur, 'next page-numbers') === false)):
                        if (strpos($cur, 'current') !== false):
                            $cur = str_replace('page-numbers current', musart_sanitize_class('nk-pagination-current'), $cur);
                        else:
                            if (strpos($cur, 'dots') !== false):
                                $cur = str_replace('class="page-numbers dots"', '', $cur);
                            else:
                                $cur = str_replace('class="page-numbers"', '', $cur);
                            endif;
                        endif;
                        echo wp_kses_post($cur);
                    endif; ?>
                <?php endforeach; ?>
            </nav>
            <?php if (isset($next_link)): ?>
                <?php if (strpos($next_link, 'next page-numbers') !== false): ?>
                    <?php echo(str_replace('next page-numbers', musart_sanitize_class('nk-pagination-next'), $next_link)); ?>
                <?php else: ?>
                    <a href="#"
                       class="nk-pagination-next <?php echo musart_sanitize_class(strpos($next_link, 'current') !== false ? 'disabled' : ''); ?>">
                        <span class="nk-icon-arrow-right"></span>
                    </a>
                <?php endif; ?>
            <?php endif; ?>
        </div>
        <?php
    }
endif;
